function CharacterPalette() {
	this.palette = [
0x00, 0x00, 0x00, // 0
0xEE, 0xAA, 0x00, // 1
0x66, 0x66, 0x66, // 2
0x44, 0x44, 0x44, // 3
0x22, 0x22, 0x22, // 4
0xEE, 0x88, 0x44, // 5
0xCC, 0x66, 0x22, // 6
0x44, 0x00, 0x00, // 7
0xAA, 0xCC, 0xCC, // 8
0x66, 0x88, 0xAA, // 9
0xEE, 0xAA, 0x88, // 10
0xCC, 0x88, 0x66, // 11
0xAA, 0x66, 0x44, // 12
0x88, 0x44, 0x22, // 13
0x66, 0x22, 0x00, // 14
0xEE, 0xCC, 0xAA, // 15
];
	this.setPaletteColor = function(data, dataIndex, paletteIndex) {
		var paletteIndex3 = (paletteIndex * 3);
		data[dataIndex]     = this.palette[paletteIndex3];     // red
		data[dataIndex + 1] = this.palette[paletteIndex3 + 1]; // green
		data[dataIndex + 2] = this.palette[paletteIndex3 + 2]; // blue
		data[dataIndex + 3] = 0xFF; // opaque
	}
}

function PaletteImage() {
	function loadPaletteImage(contents, contentOffset) {
		var intArray = new Uint8Array(contents.buffer);
		var startIndex = contentOffset;
		var endIndex = startIndex + 0x220;
		return intArray.slice(startIndex, endIndex);
	}

	this.loadFromAmberCharFile = function(contents, contentOffset, maxSize) {
		// Image is at offset 0x7EE, has length of 0x220
		if ((0x22E + maxSize) >= (0x7EE + 0x220)) {
			this.imageContent = loadPaletteImage(contents, contentOffset + 0x7EE);
		} else {
			this.imageContent = [];
		}
	}
	
	this.writeToAmberCharFile = function(contents, contentOffset, valueArray) {
		// Image is at offset 0x7EE, has length of 0x220
		var intArray = new Uint8Array(contents.buffer);
		var startIndex = contentOffset + 0x7EE;
		if (valueArray.length == 0x220) {
			intArray.set(valueArray, startIndex);
		}
	}
	
	this.loadFromCharacterGraphicsFile = function(contents, contentOffset) {
		this.imageContent = loadPaletteImage(contents, contentOffset + 0x01);
	}
	
	this.isValidImage = function() {
		return (this.imageContent.length > 0);
	}
	
	this.palette = new CharacterPalette();
	this.canvas = document.createElement('canvas');
	this.canvas.setAttribute("width", 32);
	this.canvas.setAttribute("height", 34);
	this.canvas.setAttribute("class", "character");
	
	this.paintCanvas = function() {
		if (!this.isValidImage()) {
			return;
		}
		const context = this.canvas.getContext('2d');
		// Disable smoothing for pixel-perfect output
		context.imageSmoothingEnabled = false;
		context.webkitImageSmoothingEnabled = false;
		context.msImageSmoothingEnabled = false;
		var charImageData = context.createImageData(32, 34);
		var bitCount = 4;
		var rowBytes = (32*4)/8;
		var chunkCount = 2;
		var bitPlaneBytes = rowBytes/4; // Note: If not dividable by 8, padding is used (not implemented)
		var bitPlaneBytesChunk = bitPlaneBytes / chunkCount;
		var chunks = true; // Repeat bit planes after each chunk of pixels
		const data = charImageData.data;
		for (var dataIndex = 0; dataIndex < data.length; dataIndex += 4) {
			var sourcePixelIndex = parseInt(dataIndex / 4);
			var sourceRowIndex = parseInt(sourcePixelIndex / 32);
			var sourceRowPixelIndex = sourcePixelIndex - (sourceRowIndex * 32);
			var byteIndex = parseInt(sourceRowPixelIndex / 8);
			var bitIndex = sourceRowPixelIndex % 8; //(sourceRowPixelIndex - (byteIndex * 8)) % 8;
			var bitMask = 0b10000000 >> bitIndex;
			var bit1; var bit2; var bit3; var bit4;
			if (chunks) {
				var chunkIndex = parseInt(byteIndex / bitPlaneBytesChunk);
				var chunkByteIndex = byteIndex - (chunkIndex * bitPlaneBytesChunk);
				bit1 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 0) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 0;
				bit2 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 1) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 1;
				bit3 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 2) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 2;
				bit4 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 3) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 3;
			} else {
				bit1 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 0) + byteIndex] & bitMask) >> (7 - bitIndex)) << 0;
				bit2 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 1) + byteIndex] & bitMask) >> (7 - bitIndex)) << 1;
				bit3 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 2) + byteIndex] & bitMask) >> (7 - bitIndex)) << 2;
				bit4 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 3) + byteIndex] & bitMask) >> (7 - bitIndex)) << 3;
			}
			var paletteIndex = (bit1 | bit2 | bit3 | bit4);
			this.palette.setPaletteColor(data, dataIndex, paletteIndex);
		}
		context.putImageData(charImageData, 0, 0);
	}
}

function IconPalette() {
	this.palette = [
0x00, 0x00, 0x00, // 0
0xAA, 0xAA, 0x88, // 1
0x88, 0x88, 0x88, // 2
0x66, 0x66, 0x44, // 3
0x22, 0x44, 0x44, // 4
0x22, 0x22, 0x22, // 5
0xCC, 0xAA, 0x22, // 6
0xCC, 0x88, 0x22, // 7
0xAA, 0x66, 0x00, // 8
0x88, 0x44, 0x00, // 9
0x66, 0x22, 0x00, // 10
0x44, 0x66, 0x88, // 11
0x22, 0x44, 0x66, // 12
0xAA, 0x66, 0x66, // 13
0x44, 0x00, 0x00, // 14
0xCC, 0xCC, 0xCC, // 15
];
	this.setPaletteColor = function(data, dataIndex, paletteIndex) {
		var paletteIndex3 = (paletteIndex * 3);
		if (paletteIndex == 0 || this.palette[paletteIndex3] != 00 || this.palette[paletteIndex3 + 1] != 00 || this.palette[paletteIndex3 + 2] != 00) {
			data[dataIndex]     = this.palette[paletteIndex3];     // red
			data[dataIndex + 1] = this.palette[paletteIndex3 + 1]; // green
			data[dataIndex + 2] = this.palette[paletteIndex3 + 2]; // blue
		} else {
			data[dataIndex]     = paletteIndex * 16;//this.palette[paletteIndex3];     // red
			data[dataIndex + 1] = paletteIndex * 16;//this.palette[paletteIndex3 + 1]; // green
			data[dataIndex + 2] = paletteIndex * 16;//this.palette[paletteIndex3 + 2]; // blue
		}
		data[dataIndex + 3] = 0xFF; // opaque
	}
}

function PaletteImageIcon(width, height, bitDepth) {
	this.loadPaletteImage = function(contents, contentOffset, byteLength) {
		var intArray = new Uint8Array(contents.buffer);
		var startIndex = contentOffset;
		//var byteLength = ((width * height) / (8 / bitDepth));
		var endIndex = startIndex + byteLength;
		this.imageContent = intArray.slice(startIndex, endIndex);
		//return byteLength;
	}
	
	this.isValidImage = function() {
		return (this.imageContent.length > 0);
	}
	
	this.width = width;
	this.height = height;
	this.bitDepth = bitDepth;
	this.palette = new IconPalette();
	this.canvas = document.createElement('canvas');
	this.canvas.setAttribute("width", width);
	this.canvas.setAttribute("height", height);
	this.canvas.setAttribute("class", "character");
	
	this.paintCanvas = function() {
		const context = this.canvas.getContext('2d');
		// Disable smoothing for pixel-perfect output
		context.imageSmoothingEnabled = false;
		context.webkitImageSmoothingEnabled = false;
		context.msImageSmoothingEnabled = false;
		var charImageData = context.createImageData(this.width, this.height);
		
		var testData = false;
		if (testData) {
			const data = charImageData.data;
			var imageIndex = 0;
			for (var dataIndex = 0; dataIndex < data.length; dataIndex += 4, imageIndex += 1) {
				var sourcePixelIndex = parseInt(dataIndex / 4);
				var sourceRowIndex = parseInt(sourcePixelIndex / this.width);
				var sourceRowPixelIndex = sourcePixelIndex - (sourceRowIndex * this.width);
				var displayValue = this.imageContent.length > imageIndex ? this.imageContent[imageIndex] : 0
				data[dataIndex]     = displayValue; // red
				data[dataIndex + 1] = displayValue; // green
				data[dataIndex + 2] = displayValue; // blue
				data[dataIndex + 3] = 0xFF; // opaque
			}
		}
		else {
			
		
		if (!this.isValidImage()) {
			return;
		}
		var bitCount = this.bitDepth;
		var rowBytes = (this.width*bitCount)/8;
		var chunkCount = 2;
		var bitPlaneBytes = rowBytes/bitCount; // Note: If not dividable by 8, padding is used (not implemented)
		var bitPlaneBytesChunk = bitPlaneBytes / chunkCount;
		var chunks = false; // Repeat bit planes after each chunk of pixels
		const data = charImageData.data;
		for (var dataIndex = 0; dataIndex < data.length; dataIndex += 4) {
			var sourcePixelIndex = parseInt(dataIndex / 4);
			var sourceRowIndex = parseInt(sourcePixelIndex / this.width);
			var sourceRowPixelIndex = sourcePixelIndex - (sourceRowIndex * this.width);
			var byteIndex = parseInt(sourceRowPixelIndex / 8);
			var bitIndex = sourceRowPixelIndex % 8; //(sourceRowPixelIndex - (byteIndex * 8)) % 8;
			var bitMask = 0b10000000 >> bitIndex;
			var bit1; var bit2; var bit3; var bit4;
			if (chunks) {
				var chunkIndex = parseInt(byteIndex / bitPlaneBytesChunk);
				var chunkByteIndex = byteIndex - (chunkIndex * bitPlaneBytesChunk);
				bit1 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 0) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 0;
				bit2 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 1) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 1;
				bit3 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 2) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 2;
				bit4 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 3) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] & bitMask) >> (7 - bitIndex)) << 3;
			} else {
				bit1 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 0) + byteIndex] & bitMask) >> (7 - bitIndex)) << 0;
				bit2 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 1) + byteIndex] & bitMask) >> (7 - bitIndex)) << 1;
				bit3 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 2) + byteIndex] & bitMask) >> (7 - bitIndex)) << 2;
				bit4 = ((this.imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 3) + byteIndex] & bitMask) >> (7 - bitIndex)) << 3;
			}
			var paletteIndex = (bit1 | bit2 | bit3 | bit4);
			this.palette.setPaletteColor(data, dataIndex, paletteIndex);
		}
		
		}
		console.log('putting image ' + this.width + 'x' + this.height);
		context.putImageData(charImageData, 0, 0);
	}
}

function PaletteImageImport() {
	this.palette = new CharacterPalette();
	
	this.getBestFitPaletteColor = function(red, green, blue) {
		var distances = [];
		for (var index = 0; index < this.palette.palette.length; index += 3) {
			distances.push(Math.abs(this.palette.palette[index] - red) + Math.abs(this.palette.palette[index + 1] - green) + Math.abs(this.palette.palette[index + 2] - blue));
			//if (this.palette.palette[index] == red && this.palette.palette[index + 1] == green && this.palette.palette[index + 2] == blue) {
			//	return parseInt(index / 3);
			//}
		}
		var minimumDistance = Number.MAX_SAFE_INTEGER;
		var minimumDistanceIndex = -1;
		for (var index = 0; index < distances.length; ++index) {
			if (distances[index] < minimumDistance) {
				minimumDistance = distances[index];
				minimumDistanceIndex = index;
			}
		}
		return minimumDistanceIndex;
	}
	
	this.readImageFile = function(imageBitmap) {
		var importCanvas = document.createElement('canvas');
		importCanvas.setAttribute("width", 32);
		importCanvas.setAttribute("height", 34);
		const context = importCanvas.getContext('2d');
		// Disable smoothing for pixel-perfect output
		context.imageSmoothingEnabled = false;
		context.webkitImageSmoothingEnabled = false;
		context.msImageSmoothingEnabled = false;
		context.drawImage(imageBitmap, 0,0,32,34);
		var charImageData = context.getImageData(0, 0, 32, 34);
		// Read rgba values and calculate palette color
		var imageContent = new Array(0x220);
		var bitCount = 4;
		var rowBytes = (32*4)/8;
		var chunkCount = 2;
		var bitPlaneBytes = rowBytes/4; // Note: If not dividable by 8, padding is used (not implemented)
		var bitPlaneBytesChunk = bitPlaneBytes / chunkCount;
		var chunks = true; // Repeat bit planes after each chunk of pixels
		const data = charImageData.data;
		for (var dataIndex = 0; dataIndex < data.length; dataIndex += 4) {
			var paletteIndex = this.getBestFitPaletteColor(data[dataIndex], data[dataIndex+1], data[dataIndex+2]);
			var bit1 = paletteIndex & 0b0001;
			var bit2 = paletteIndex & 0b0010;
			var bit3 = paletteIndex & 0b0100;
			var bit4 = paletteIndex & 0b1000;
			var sourcePixelIndex = parseInt(dataIndex / 4);
			var sourceRowIndex = parseInt(sourcePixelIndex / 32);
			var sourceRowPixelIndex = sourcePixelIndex - (sourceRowIndex * 32);
			var byteIndex = parseInt(sourceRowPixelIndex / 8);
			var bitIndex = sourceRowPixelIndex % 8; //(sourceRowPixelIndex - (byteIndex * 8)) % 8;
			var bitMask = 0b10000000 >> bitIndex;
			if (chunks) {
				var chunkIndex = parseInt(byteIndex / bitPlaneBytesChunk);
				var chunkByteIndex = byteIndex - (chunkIndex * bitPlaneBytesChunk);
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 0) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] |= ((bit1 >> 0) << (7 - bitIndex));
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 1) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] |= ((bit2 >> 1) << (7 - bitIndex));
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 2) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] |= ((bit3 >> 2) << (7 - bitIndex));
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytesChunk * 3) + (bitPlaneBytesChunk * bitCount * chunkIndex) + (chunkByteIndex)] |= ((bit4 >> 3) << (7 - bitIndex));
			} else {
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 0) + byteIndex] |= ((bit1 >> 0) << (7 - bitIndex));
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 1) + byteIndex] |= ((bit2 >> 1) << (7 - bitIndex));
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 2) + byteIndex] |= ((bit3 >> 2) << (7 - bitIndex));
				imageContent[(rowBytes * sourceRowIndex) + (bitPlaneBytes * 3) + byteIndex] |= ((bit4 >> 3) << (7 - bitIndex));
			}
		}
		return imageContent;
	}
}

function readImageFile(e, characterIndex) {
	var file = e.target.files[0];
	if (!file) {
		return;
	}
	var paletteImageImport = new PaletteImageImport();
	createImageBitmap(file).then(imageBitmap => {
		var imageContent = paletteImageImport.readImageFile(imageBitmap);
		var currentCharacterImage = window.currentFile.characters[characterIndex].stats.characterImage;
		currentCharacterImage.imageContent = imageContent;
		currentCharacterImage.paintCanvas();
	});
}

function CharacterGraphics() {
	// Loading data from file was not successful because of CORS policies, so putting the data here as a copy.
	var data = [0x41, 0x4D, 0x42, 0x52, 0x43, 0x01, 0x0C, 0x01, 0x00, 0x10, 0x00, 0x1E, 0x00, 0x1E, 0x00, 0x0E, 0x54, 0x00, 0x6C, 0x00, 0x7C, 0x00, 0x38, 0x00, 0x00, 0xC8, 0x00, 0xF7, 0x00, 0xFF, 0x00, 0x3F, 0xBA, 0x00, 0xC6, 0x00, 0xFE, 0x00, 0x7C, 0x00, 0x01, 0x2D, 0x01, 0xC3, 0x01, 0xFF, 0x00, 0xFE, 0x49, 0x00, 0x87, 0x00, 0xFF, 0x00, 0xFE, 0x00, 0x02, 0xC4, 0x03, 0x03, 0x03, 0xFF, 0x01, 0xFF, 0x64, 0x80, 0x83, 0x80, 0xFF, 0x80, 0xFF, 0x00, 0x05, 0xB9, 0x06, 0x38, 0x07, 0xC7, 0x03, 0xFF, 0x5A, 0x00, 0x81, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x00, 0x46, 0x06, 0x46, 0x07, 0xB9, 0x07, 0xFF, 0xAE, 0x40, 0x21, 0xC0, 0xDF, 0xC0, 0xFF, 0x80, 0x02, 0x30, 0x04, 0x00, 0x07, 0xFF, 0x07, 0xFF, 0x1D, 0x20, 0x02, 0xE0, 0xFF, 0xE0, 0xFF, 0xC0, 0x0E, 0xD5, 0x08, 0x20, 0x0F, 0xFF, 0x07, 0xFF, 0xB6, 0x40, 0x09, 0xE0, 0xFF, 0xE0, 0xFF, 0xA0, 0x03, 0x27, 0x0C, 0xF8, 0x0F, 0xFF, 0x0F, 0xDF, 0x63, 0xB0, 0x9C, 0x70, 0xFF, 0xF0, 0xFF, 0xC0, 0x06, 0x4C, 0x09, 0xF3, 0x0F, 0xFF, 0x0F, 0xBF, 0x91, 0xA0, 0xEE, 0x70, 0xFF, 0xF0, 0x7F, 0xD0, 0x16, 0x08, 0x19, 0xEB, 0x1F, 0xF7, 0x0F, 0xFF, 0x85, 0x40, 0xCE, 0x30, 0x7F, 0xF0, 0xFB, 0xF0, 0x0A, 0x42, 0x11, 0xFB, 0x1F, 0xFC, 0x1F, 0xBF, 0x64, 0x68, 0x5B, 0x18, 0xBF, 0xF8, 0xFF, 0xF0, 0x2B, 0xB3, 0x30, 0xCF, 0x3F, 0xFC, 0x1F, 0x7F, 0x4D, 0xA0, 0x33, 0x18, 0xFF, 0xF8, 0xFE, 0xF8, 0x09, 0x75, 0x30, 0xB1, 0x3F, 0xA6, 0x3F, 0xCF, 0x9F, 0xA0, 0x59, 0x18, 0xCB, 0xF8, 0xE6, 0xF8, 0x53, 0x0F, 0x60, 0x83, 0x7F, 0xFC, 0x3F, 0xFF, 0xDC, 0x50, 0x21, 0x88, 0xFF, 0xF8, 0xFF, 0xF8, 0x11, 0x1B, 0x62, 0xFB, 0x7F, 0x84, 0x7F, 0xFF, 0xC3, 0x70, 0x01, 0xC8, 0xFF, 0xF8, 0xFE, 0xB8, 0x34, 0xCF, 0x43, 0x7F, 0x7F, 0x80, 0x7F, 0xFF, 0x55, 0xD4, 0x13, 0x2C, 0xEF, 0xFC, 0xFE, 0xF8, 0x29, 0x2F, 0x42, 0x3F, 0x7F, 0xC0, 0x7F, 0xFF, 0x28, 0xE4, 0x26, 0x1C, 0xDF, 0xFC, 0xFF, 0xF8, 0x45, 0x3E, 0x62, 0xBE, 0x7F, 0xC1, 0x3F, 0xFF, 0x80, 0xA0, 0x0F, 0x1C, 0xFF, 0xFC, 0xFF, 0xFC, 0x4D, 0xE7, 0x6B, 0xFF, 0x77, 0xC0, 0x3E, 0x3F, 0x09, 0x30, 0x07, 0x8C, 0xFF, 0xFC, 0xFE, 0xFC, 0x0A, 0xFA, 0x29, 0xF9, 0x37, 0xC7, 0x3F, 0x3F, 0x9B, 0xB0, 0x07, 0x0C, 0xFF, 0xFC, 0xFC, 0xFC, 0x12, 0xC8, 0x21, 0xC7, 0x3F, 0xFF, 0x3F, 0x3F, 0x2B, 0x70, 0xC7, 0x0C, 0xFF, 0xFC, 0xFC, 0xFC, 0x0B, 0x64, 0x30, 0xE3, 0x3F, 0xFF, 0x3F, 0x9F, 0x57, 0x68, 0x8E, 0x1C, 0xFF, 0xFC, 0xF9, 0xF4, 0x28, 0xA9, 0x30, 0x6F, 0x3F, 0xF0, 0x1F, 0xDF, 0x97, 0xD4, 0x8E, 0x3C, 0x7F, 0xFC, 0xF9, 0xE8, 0x05, 0xB7, 0x18, 0x67, 0x1F, 0xF8, 0x1F, 0xDF, 0xA5, 0xE0, 0x9E, 0x18, 0x7F, 0xF8, 0xFB, 0xF8, 0x12, 0x5C, 0x1D, 0xE0, 0x1F, 0xFF, 0x0F, 0xBF, 0x64, 0xC8, 0x1F, 0x38, 0xFF, 0xF8, 0xFB, 0xF0, 0x06, 0x8F, 0x07, 0x60, 0x07, 0xFF, 0x01, 0xFF, 0xF0, 0xB0, 0x0F, 0x70, 0xFF, 0xF0, 0xFF, 0xC0, 0x01, 0x7B, 0x01, 0xF8, 0x01, 0xC7, 0x00, 0xBF, 0xFF, 0x40, 0x05, 0xC0, 0xFF, 0xC0, 0xFA, 0x80, 0x01, 0xFE, 0x01, 0xFE, 0x02, 0xF1, 0x03, 0xFF, 0xF8, 0x00, 0x07, 0x80, 0xF8, 0x00, 0xFF, 0x80, 0x18, 0xFF, 0x1E, 0xFF, 0x3F, 0x7C, 0x27, 0xFF, 0xFE, 0xF8, 0xFF, 0xF8, 0x3E, 0x78, 0xFF, 0x80, 0xA4, 0xFF, 0xFA, 0xFF, 0x1F, 0x7F, 0xFF, 0xFF, 0xFF, 0xBE, 0xFF, 0xFE, 0xFF, 0x79, 0xFF, 0xC7, 0x69, 0xFF, 0xF2, 0xFF, 0x5F, 0x3F, 0xFF, 0xFF, 0xFE, 0x1D, 0xFF, 0x7F, 0xFE, 0xF8, 0xFF, 0xE7, 0xEA, 0xBF, 0xF1, 0x3F, 0xDF, 0xDF, 0xFF, 0xFF, 0x7C, 0x6C, 0xFC, 0x9F, 0x7F, 0xF8, 0xFF, 0xF7, 0xE5, 0x1E, 0xF8, 0xDF, 0xDF, 0xEE, 0xFF, 0xFF, 0xB8, 0xAE, 0xFB, 0x1F, 0x3F, 0xFA, 0xFF, 0xF7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x1E, 0x00, 0x20, 0x00, 0x00, 0x54, 0x00, 0x6C, 0x00, 0x02, 0x00, 0x10, 0x00, 0x00, 0x48, 0x00, 0x77, 0x00, 0x80, 0x00, 0x08, 0xBA, 0x00, 0xC6, 0x00, 0x01, 0x00, 0x38, 0x00, 0x00, 0x2D, 0x00, 0xC3, 0x01, 0x00, 0x00, 0x3C, 0x49, 0x00, 0x87, 0x00, 0x00, 0x80, 0x78, 0x00, 0x00, 0xC4, 0x01, 0x03, 0x02, 0x00, 0x00, 0xFC, 0x64, 0x80, 0x83, 0x80, 0x00, 0x00, 0x7C, 0x00, 0x01, 0xB9, 0x02, 0x38, 0x04, 0x38, 0x01, 0xFF, 0x5A, 0x00, 0x81, 0x80, 0x00, 0x40, 0x7E, 0x00, 0x00, 0x46, 0x06, 0x46, 0x00, 0x46, 0x01, 0xFF, 0xAE, 0x40, 0x21, 0xC0, 0x20, 0x20, 0xFE, 0x00, 0x02, 0x30, 0x04, 0x00, 0x00, 0x00, 0x03, 0xFF, 0x1D, 0x20, 0x02, 0xE0, 0x00, 0x00, 0xFD, 0x00, 0x06, 0xD5, 0x00, 0x20, 0x08, 0x00, 0x07, 0xDF, 0xB6, 0x40, 0x09, 0xE0, 0x00, 0x10, 0xF6, 0x00, 0x03, 0x27, 0x0C, 0xF8, 0x00, 0x00, 0x03, 0x07, 0x63, 0xB0, 0x9C, 0x70, 0x00, 0x00, 0x63, 0x80, 0x06, 0x4C, 0x09, 0xF3, 0x00, 0x00, 0x06, 0x0C, 0x91, 0xA0, 0xEE, 0x70, 0x00, 0x00, 0x11, 0x80, 0x06, 0x48, 0x09, 0xCF, 0x10, 0x30, 0x06, 0x3C, 0x85, 0x40, 0xCE, 0x30, 0xB0, 0x08, 0xB1, 0xC0, 0x1A, 0xDA, 0x11, 0xC3, 0x00, 0x3C, 0x0E, 0x7F, 0xD8, 0x68, 0xC3, 0x18, 0xBC, 0x00, 0xFC, 0xE0, 0x0B, 0x6D, 0x10, 0x61, 0x20, 0x9E, 0x0F, 0xFF, 0xB3, 0xA0, 0x81, 0x18, 0x7E, 0x00, 0xFE, 0xE0, 0x2D, 0x69, 0x30, 0x59, 0x00, 0x92, 0x0F, 0xF7, 0xD5, 0xA0, 0x98, 0x18, 0x4B, 0x04, 0xEF, 0xE0, 0x1B, 0x39, 0x21, 0x79, 0x40, 0x86, 0x1E, 0xFF, 0x22, 0x54, 0x83, 0x8C, 0x7C, 0x00, 0xFE, 0x70, 0x51, 0x32, 0x63, 0x7F, 0x00, 0xB0, 0x1C, 0xFF, 0x1D, 0x70, 0x9C, 0x8C, 0x63, 0x40, 0xFF, 0x70, 0x35, 0x58, 0x43, 0xFF, 0x00, 0x18, 0x3D, 0xFF, 0xCB, 0xD0, 0xD8, 0x2C, 0xA7, 0x02, 0xFF, 0xD0, 0x28, 0xE8, 0x42, 0xFF, 0x01, 0x08, 0x3D, 0xFF, 0x56, 0xE2, 0xF0, 0x1E, 0x0F, 0x00, 0xFF, 0xE0, 0x2B, 0xA0, 0x45, 0x3F, 0x00, 0xC0, 0x3A, 0xFF, 0xFE, 0xA0, 0xF1, 0x1E, 0x0E, 0x00, 0xFE, 0xE0, 0x2B, 0x05, 0x47, 0x9C, 0x00, 0xE3, 0x38, 0xFF, 0xA5, 0x38, 0x22, 0x86, 0xDF, 0x00, 0xFF, 0x78, 0x25, 0x75, 0x43, 0x93, 0x00, 0xEF, 0x3C, 0xFF, 0xAF, 0x34, 0xC0, 0x0A, 0xFF, 0x00, 0xFF, 0xF4, 0x2D, 0xC8, 0x43, 0x2A, 0x00, 0xF7, 0x3C, 0xFE, 0x0B, 0x74, 0x44, 0x0A, 0xFF, 0x00, 0x7F, 0xF4, 0x1E, 0xAD, 0x61, 0xCC, 0x00, 0x73, 0x1E, 0x7F, 0xAF, 0x68, 0x20, 0x1E, 0xDE, 0x00, 0xFF, 0xE0, 0x13, 0x64, 0x60, 0xC7, 0x00, 0x38, 0x1F, 0x3F, 0x5F, 0xD2, 0xC0, 0x3E, 0x3E, 0x00, 0xFF, 0xC0, 0x0B, 0x71, 0x70, 0xD1, 0x80, 0x2E, 0x0F, 0x3F, 0x9E, 0xA6, 0x81, 0x1E, 0x7E, 0x00, 0xFE, 0xE0, 0xA4, 0x88, 0xDB, 0xD8, 0x00, 0x27, 0x24, 0x3F, 0x0F, 0x5A, 0x00, 0x86, 0xFF, 0x00, 0xFF, 0x78, 0x2E, 0xA2, 0xD1, 0xC6, 0x00, 0x19, 0x2E, 0x1F, 0x0B, 0x5E, 0x04, 0x82, 0xFF, 0x00, 0xF3, 0x7C, 0x55, 0x38, 0xB8, 0x93, 0x00, 0x5C, 0x47, 0x57, 0xB6, 0x64, 0x89, 0x9A, 0x7E, 0x01, 0xC6, 0x64, 0x6B, 0x0C, 0x90, 0xC5, 0x00, 0x36, 0x6F, 0xF7, 0x59, 0x37, 0xA6, 0x49, 0x38, 0x00, 0x99, 0xB6, 0xDD, 0x87, 0x03, 0x71, 0x13, 0x89, 0xFE, 0xFB, 0xA1, 0xCB, 0x4E, 0x35, 0x70, 0x30, 0xBF, 0xFA, 0x16, 0xC3, 0xA1, 0xB8, 0xFF, 0xC4, 0xFF, 0x7F, 0x42, 0xC7, 0x1D, 0xBF, 0x63, 0xFF, 0xFF, 0x78, 0xA9, 0x62, 0x10, 0xD8, 0xFF, 0xE4, 0xFF, 0xBF, 0x44, 0xCF, 0x1B, 0x3F, 0xE7, 0xFF, 0xFF, 0xF0, 0xA9, 0x63, 0x10, 0xD8, 0xFF, 0xE7, 0xFF, 0xBF, 0xC4, 0xC7, 0x1B, 0x3F, 0xE7, 0xFF, 0xFF, 0xF8, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x2D, 0x00, 0x32, 0x00, 0x3F, 0x00, 0x19, 0x3E, 0x00, 0x01, 0x00, 0x37, 0x00, 0x23, 0x00, 0x00, 0x2E, 0x00, 0x51, 0x00, 0x7B, 0x00, 0x60, 0xBF, 0x80, 0x40, 0x80, 0xE7, 0x80, 0x81, 0x00, 0x00, 0xDF, 0x00, 0xA8, 0x00, 0xFB, 0x00, 0x48, 0x7F, 0x00, 0x9C, 0x80, 0xDD, 0x80, 0x1C, 0x80, 0x01, 0x3F, 0x01, 0xDC, 0x01, 0xDD, 0x00, 0x9C, 0xFF, 0xC0, 0x04, 0x40, 0xC5, 0xC0, 0x04, 0x80, 0x00, 0xBD, 0x01, 0x78, 0x01, 0xFB, 0x01, 0xBB, 0x0F, 0x00, 0x42, 0xC0, 0xF2, 0xC0, 0xB2, 0x40, 0x03, 0x7A, 0x02, 0xA4, 0x03, 0xA7, 0x01, 0x23, 0x1F, 0x60, 0x00, 0xA0, 0xF9, 0xE0, 0xF8, 0x40, 0x00, 0xF5, 0x03, 0x69, 0x03, 0xEE, 0x02, 0x67, 0xB3, 0x80, 0xF5, 0x60, 0x0F, 0xE0, 0xF9, 0x20, 0x06, 0xEB, 0x05, 0x93, 0x07, 0x9D, 0x02, 0x8F, 0x9F, 0xF0, 0xF8, 0x10, 0x84, 0x70, 0xFC, 0x20, 0x01, 0xF7, 0x06, 0x07, 0x07, 0x7B, 0x04, 0x1F, 0xBC, 0xC0, 0xFB, 0xB0, 0x87, 0xB0, 0xFC, 0x90, 0x07, 0xDB, 0x00, 0x2F, 0x06, 0xB3, 0x04, 0x1F, 0x33, 0xD0, 0xF0, 0x60, 0x0E, 0x70, 0xFE, 0x50, 0x0B, 0x47, 0x0C, 0x87, 0x0D, 0xF9, 0x00, 0x3F, 0x41, 0xC0, 0xC0, 0x70, 0x3F, 0xF0, 0xFE, 0x40, 0x03, 0x65, 0x0C, 0x99, 0x0D, 0xFE, 0x08, 0x3F, 0x27, 0xE0, 0x98, 0x50, 0x7F, 0xF0, 0xFE, 0x40, 0x1E, 0xD2, 0x11, 0x0C, 0x1D, 0xFF, 0x08, 0x3F, 0x4E, 0x68, 0x31, 0x98, 0xFF, 0x98, 0xFE, 0x00, 0x06, 0xFA, 0x19, 0x18, 0x19, 0x13, 0x10, 0x27, 0x1F, 0x60, 0x58, 0x98, 0xCB, 0x98, 0xE7, 0x08, 0x1E, 0xC6, 0x01, 0x00, 0x1F, 0x7F, 0x10, 0x3F, 0xDC, 0xF8, 0xA0, 0x00, 0x7F, 0xD8, 0xFF, 0x08, 0x05, 0xCD, 0x1A, 0x3D, 0x1B, 0x42, 0x00, 0x3F, 0xE3, 0x50, 0x80, 0xA8, 0x7F, 0xF8, 0xFF, 0x00, 0x2D, 0xA7, 0x32, 0x3F, 0x3B, 0xC0, 0x00, 0x7F, 0x34, 0xEC, 0x93, 0x14, 0x6F, 0xBC, 0xFF, 0x80, 0x1F, 0x17, 0x22, 0x1F, 0x37, 0xE0, 0x22, 0xFF, 0xA8, 0x68, 0xA7, 0x14, 0x5F, 0x9C, 0xFF, 0x84, 0x3F, 0x5F, 0x04, 0x9F, 0x36, 0xE0, 0x24, 0xFF, 0x00, 0xFC, 0x0F, 0x20, 0xFF, 0xBC, 0xFF, 0xA4, 0x1E, 0xBC, 0x25, 0x5C, 0x35, 0xE3, 0x04, 0xFF, 0x18, 0x78, 0x07, 0xA4, 0xFF, 0xEC, 0xFF, 0x20, 0x1F, 0x05, 0x2C, 0xE3, 0x3D, 0xFF, 0x0C, 0x7E, 0xB1, 0x7C, 0xCE, 0xE0, 0xFF, 0xEC, 0x7F, 0x64, 0x3F, 0xF2, 0x08, 0x21, 0x3D, 0x7F, 0x28, 0x5F, 0x54, 0x78, 0x8F, 0xC4, 0xFF, 0xCC, 0xFA, 0x44, 0x1F, 0x94, 0x20, 0x67, 0x31, 0xF8, 0x20, 0x3F, 0x92, 0xFC, 0x8D, 0x44, 0x7F, 0x7C, 0xFE, 0x40, 0x2F, 0x7B, 0x36, 0x83, 0x3F, 0xBC, 0x06, 0x3F, 0xA0, 0xD0, 0x9F, 0x28, 0x7F, 0xB8, 0xFC, 0x00, 0x1F, 0x4E, 0x02, 0xA0, 0x1B, 0xFF, 0x12, 0x1F, 0x61, 0xD8, 0x1E, 0x20, 0xFF, 0x78, 0xFC, 0x08, 0x0F, 0x37, 0x11, 0xD0, 0x19, 0xCF, 0x11, 0x1F, 0xF1, 0xA0, 0x0E, 0x58, 0xFF, 0x78, 0xFC, 0x08, 0x1D, 0xFD, 0x12, 0x1C, 0x1B, 0x43, 0x00, 0x1F, 0xFB, 0xB8, 0x04, 0xC8, 0xFF, 0xF8, 0xFC, 0x90, 0x26, 0xFF, 0x39, 0x1F, 0x3F, 0x60, 0x10, 0x1F, 0x7D, 0xE4, 0x02, 0x9C, 0xFF, 0xBC, 0xFC, 0x88, 0x5E, 0xDF, 0x61, 0x1F, 0x7D, 0xE0, 0x20, 0x3F, 0xFF, 0xE0, 0xFC, 0x5C, 0x03, 0x5C, 0xFE, 0x44, 0x74, 0xB7, 0x03, 0x07, 0xDB, 0xF8, 0x88, 0x7F, 0xF9, 0xF7, 0xF8, 0x0A, 0x07, 0x5F, 0xFE, 0x05, 0x9C, 0xF6, 0x81, 0x08, 0x77, 0x47, 0xF2, 0x77, 0x07, 0xD8, 0x00, 0x06, 0xFA, 0x2F, 0xFC, 0x23, 0xF9, 0xDE, 0xE6, 0x21, 0x0F, 0x40, 0xE0, 0x5E, 0x4A, 0xFE, 0xB1, 0x00, 0x01, 0x57, 0x4C, 0x13, 0xFF, 0xDE, 0xF4, 0x21, 0x02, 0xC0, 0xF4, 0x5E, 0x4A, 0xDE, 0xB1, 0x00, 0x01, 0x97, 0x4E, 0x3B, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x0E, 0x00, 0x0E, 0x00, 0x10, 0x00, 0x00, 0x28, 0x00, 0x38, 0x00, 0x44, 0x00, 0x00, 0x00, 0x00, 0x37, 0x00, 0x3F, 0x00, 0xC0, 0x00, 0x00, 0x44, 0x00, 0x7C, 0x00, 0x82, 0x00, 0x00, 0x00, 0x00, 0xD2, 0x00, 0xEE, 0x01, 0x01, 0x00, 0x10, 0xB6, 0x00, 0xCE, 0x00, 0x01, 0x00, 0x30, 0x00, 0x01, 0x3B, 0x01, 0xC7, 0x02, 0x00, 0x00, 0x38, 0x9B, 0x00, 0xE7, 0x00, 0x00, 0x80, 0x18, 0x00, 0x02, 0x46, 0x03, 0x81, 0x04, 0x00, 0x00, 0x7E, 0xA5, 0x80, 0xDB, 0x80, 0x00, 0x00, 0x24, 0x00, 0x07, 0xB9, 0x06, 0x00, 0x00, 0x00, 0x01, 0xFF, 0x51, 0x80, 0x8F, 0x80, 0x00, 0x40, 0x70, 0x00, 0x05, 0xCF, 0x06, 0x30, 0x00, 0x00, 0x01, 0xCF, 0xE2, 0xC0, 0x1F, 0xC0, 0x00, 0x20, 0xE0, 0x00, 0x01, 0x2A, 0x06, 0xF5, 0x08, 0x00, 0x01, 0x0A, 0x49, 0xA0, 0xBF, 0xA0, 0x00, 0x40, 0x40, 0x00, 0x0C, 0xF8, 0x0F, 0xDF, 0x00, 0x20, 0x00, 0x20, 0x9C, 0x40, 0xFF, 0xC0, 0x00, 0x30, 0x00, 0x00, 0x09, 0xF3, 0x0F, 0xBF, 0x00, 0x40, 0x00, 0x40, 0xEE, 0x50, 0x7F, 0xD0, 0x80, 0x20, 0x80, 0x00, 0x09, 0x8F, 0x0F, 0x8F, 0x00, 0x70, 0x00, 0x7C, 0xCE, 0xB0, 0xCB, 0x70, 0x34, 0x00, 0xB4, 0x80, 0x05, 0x2D, 0x0B, 0x77, 0x10, 0xF9, 0x04, 0xDF, 0xD3, 0x90, 0xBB, 0x70, 0x7C, 0x08, 0xEC, 0x80, 0x14, 0x5F, 0x1B, 0x3B, 0x00, 0xFC, 0x04, 0xE7, 0xEF, 0x58, 0x70, 0xB8, 0xFF, 0x00, 0x9F, 0x40, 0x12, 0x47, 0x1D, 0x03, 0x20, 0xB4, 0x02, 0xCF, 0x0B, 0x58, 0x80, 0xB8, 0xB7, 0x00, 0xCF, 0x40, 0x25, 0x5A, 0x3A, 0xC3, 0x01, 0x3C, 0x05, 0xFF, 0xA5, 0xA8, 0x45, 0xD8, 0xFA, 0x04, 0xFE, 0x20, 0x2F, 0x9B, 0x32, 0xFB, 0x41, 0x04, 0x0D, 0xFF, 0xC3, 0xCC, 0x00, 0xBC, 0xFF, 0x40, 0xFF, 0x40, 0x0B, 0x4F, 0x37, 0x7F, 0x40, 0x80, 0x09, 0xFF, 0x55, 0x2C, 0x12, 0xFC, 0xEF, 0x00, 0xFF, 0x00, 0x56, 0x2F, 0x6A, 0x3F, 0x01, 0xC0, 0x15, 0xFF, 0x28, 0x1C, 0x26, 0xFC, 0xDF, 0x02, 0xFF, 0x00, 0x54, 0xBE, 0x6E, 0x3E, 0x01, 0xC1, 0x11, 0xFF, 0x81, 0x5E, 0x0F, 0xBE, 0xFE, 0x00, 0xFE, 0x40, 0x57, 0x27, 0x6C, 0xBF, 0x03, 0xC0, 0x13, 0xFF, 0x09, 0xC6, 0x06, 0xBE, 0xFF, 0x00, 0xFF, 0x40, 0x5B, 0x73, 0x66, 0xB3, 0x01, 0xCC, 0x19, 0xFF, 0x3B, 0xCA, 0x24, 0x3E, 0xDF, 0x00, 0xFF, 0xC0, 0x53, 0xC8, 0x6E, 0x07, 0x01, 0xFF, 0x11, 0xFF, 0x4B, 0x8A, 0x84, 0x7E, 0xFF, 0x00, 0xFF, 0x80, 0x61, 0xB3, 0x7F, 0x50, 0x00, 0xEF, 0x00, 0xFF, 0x36, 0x96, 0x29, 0x76, 0xDE, 0x08, 0xFE, 0x80, 0x6C, 0xE9, 0x73, 0x8F, 0x00, 0x70, 0x0C, 0x7F, 0x96, 0x2C, 0x89, 0xEC, 0x7E, 0x12, 0xFE, 0x00, 0x74, 0xF7, 0x7B, 0x87, 0x00, 0x78, 0x04, 0x7F, 0xA7, 0x58, 0x99, 0xB8, 0x7E, 0x06, 0xFE, 0x40, 0x5B, 0xDC, 0x7F, 0x40, 0x80, 0xBF, 0x00, 0xBF, 0x67, 0xA4, 0x18, 0xDC, 0xFF, 0x02, 0xFF, 0x20, 0xD1, 0xEF, 0xFF, 0x60, 0x00, 0x9F, 0x00, 0xBF, 0xF3, 0xA0, 0x0C, 0xDC, 0xFF, 0x02, 0xFF, 0x20, 0xAA, 0xFB, 0xED, 0xF8, 0x10, 0x07, 0x02, 0x7F, 0xFF, 0x9A, 0x01, 0xFE, 0xFE, 0x00, 0xFE, 0x00, 0x94, 0xFE, 0xFB, 0xFE, 0x00, 0x01, 0x04, 0xFF, 0xFE, 0xC8, 0x07, 0x7E, 0xF8, 0x01, 0xF8, 0x80, 0x32, 0xFF, 0xDC, 0xFF, 0x01, 0x00, 0x23, 0xFF, 0xFE, 0x04, 0xFF, 0xFE, 0x00, 0x01, 0xFE, 0x00, 0xFA, 0xFF, 0xE0, 0xFF, 0x01, 0x00, 0xFF, 0xFF, 0xFF, 0xC1, 0xFF, 0xB8, 0x00, 0x07, 0xFF, 0xC7, 0x32, 0xFF, 0xE0, 0xFF, 0x01, 0x00, 0xFF, 0xFF, 0xFF, 0xE0, 0xFF, 0x98, 0x00, 0x07, 0xFF, 0xE7, 0xF9, 0x3F, 0xE0, 0x3F, 0x00, 0xC0, 0xFF, 0xFF, 0xFF, 0xD3, 0xFF, 0x0B, 0x00, 0x04, 0xFF, 0xF7, 0xF8, 0xDF, 0xE0, 0x1F, 0x00, 0x20, 0xFF, 0xFF, 0x7F, 0x93, 0x7C, 0x0B, 0x80, 0x04, 0xFF, 0xF7, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x9F, 0x00, 0xE0, 0x00, 0xF9, 0x00, 0x40, 0x72, 0x00, 0x8E, 0x00, 0xDE, 0x00, 0x04, 0x00, 0x00, 0x34, 0x00, 0xCF, 0x00, 0xF0, 0x00, 0xB0, 0x80, 0x00, 0x9E, 0x00, 0x7E, 0x00, 0x12, 0x00, 0x00, 0x79, 0x00, 0x9E, 0x00, 0xE3, 0x00, 0x61, 0x40, 0x00, 0xCE, 0x00, 0xBE, 0x00, 0x08, 0x00, 0x01, 0xA7, 0x01, 0x5A, 0x01, 0xFA, 0x00, 0xE2, 0xD1, 0x00, 0x2F, 0x00, 0x3F, 0x00, 0x1C, 0x00, 0x00, 0x3F, 0x01, 0xD6, 0x01, 0xD6, 0x01, 0x16, 0xEC, 0x00, 0x93, 0x00, 0x9F, 0x00, 0x8F, 0x00, 0x00, 0xFF, 0x01, 0x01, 0x01, 0xBD, 0x00, 0x01, 0xF3, 0x00, 0x0C, 0x00, 0x7F, 0x00, 0x03, 0x00, 0x03, 0xB9, 0x02, 0xC2, 0x03, 0xFF, 0x00, 0xBC, 0x35, 0x80, 0x8A, 0x80, 0xFF, 0x80, 0x71, 0x00, 0x01, 0x64, 0x03, 0xA4, 0x03, 0xDF, 0x01, 0x5F, 0x0E, 0x80, 0x21, 0x00, 0xDF, 0x80, 0xFC, 0x80, 0x03, 0xC7, 0x00, 0x5F, 0x03, 0xA7, 0x00, 0xBF, 0x3E, 0x80, 0xF9, 0x00, 0x07, 0x80, 0xFE, 0x80, 0x03, 0x06, 0x00, 0x9F, 0x02, 0xE6, 0x00, 0xFF, 0x34, 0x80, 0xF3, 0x00, 0x0F, 0x80, 0xFE, 0x80, 0x01, 0x0E, 0x02, 0x0F, 0x02, 0xF2, 0x02, 0xFF, 0xC0, 0x80, 0xC1, 0x80, 0x3F, 0x80, 0xFE, 0x00, 0x01, 0x35, 0x02, 0x87, 0x03, 0xF9, 0x02, 0xFF, 0xB5, 0x00, 0x84, 0x80, 0x7B, 0x80, 0xFF, 0x80, 0x01, 0x5B, 0x00, 0xC3, 0x03, 0xBC, 0x02, 0xFF, 0x62, 0x80, 0x00, 0x00, 0xFF, 0x80, 0xFE, 0x80, 0x02, 0xA3, 0x02, 0xB3, 0x01, 0x04, 0x03, 0xCF, 0x93, 0x00, 0x30, 0x00, 0x87, 0x80, 0xCF, 0x80, 0x03, 0x12, 0x02, 0xF3, 0x01, 0x0C, 0x01, 0xFF, 0x5D, 0x00, 0x1C, 0x00, 0xE3, 0x80, 0xFF, 0x80, 0x01, 0x9B, 0x00, 0xFB, 0x03, 0x04, 0x03, 0xFF, 0xC2, 0x00, 0x01, 0x00, 0xFF, 0x80, 0xFF, 0x80, 0x01, 0x4F, 0x03, 0x7F, 0x02, 0x80, 0x03, 0xFF, 0x54, 0x00, 0x12, 0x80, 0xEF, 0x80, 0xFF, 0x80, 0x02, 0x2F, 0x02, 0x3F, 0x03, 0xC0, 0x01, 0xFF, 0x28, 0x80, 0x26, 0x80, 0xDF, 0x80, 0xFF, 0x00, 0x00, 0xBE, 0x01, 0x3E, 0x01, 0xC1, 0x01, 0xFF, 0x80, 0x00, 0x0F, 0x00, 0xFF, 0x00, 0xFF, 0x00, 0x02, 0x27, 0x01, 0xBF, 0x03, 0xC0, 0x03, 0xFF, 0x08, 0x00, 0x07, 0x00, 0xFF, 0x00, 0xFF, 0x00, 0x01, 0x7A, 0x02, 0xB9, 0x03, 0xC7, 0x03, 0xFF, 0x98, 0x00, 0x07, 0x00, 0xFF, 0x00, 0xFE, 0x00, 0x02, 0xC8, 0x03, 0x87, 0x03, 0xFF, 0x00, 0x7F, 0x28, 0x00, 0xC7, 0x00, 0xFF, 0x00, 0xFD, 0x00, 0x01, 0xA4, 0x00, 0x43, 0x01, 0xFF, 0x00, 0xFF, 0x51, 0x00, 0x8F, 0x00, 0xFF, 0x00, 0xFC, 0x00, 0x02, 0x69, 0x03, 0xCF, 0x03, 0xF0, 0x00, 0x3F, 0x93, 0x00, 0x8D, 0x00, 0x7F, 0x00, 0xF8, 0x00, 0x00, 0xB7, 0x03, 0x47, 0x03, 0x78, 0x02, 0x7F, 0xA2, 0x00, 0x9D, 0x00, 0x7D, 0x00, 0xF9, 0x00, 0x01, 0xBC, 0x02, 0x40, 0x03, 0x7F, 0x00, 0x3F, 0x66, 0x80, 0x19, 0x80, 0xFF, 0x80, 0xFC, 0x00, 0x01, 0x5F, 0x02, 0xA0, 0x02, 0xFF, 0x00, 0x5F, 0xF0, 0x00, 0x0F, 0x80, 0xFF, 0x80, 0xFC, 0x80, 0x05, 0x3B, 0x06, 0xD8, 0x06, 0xE7, 0x00, 0x3F, 0xFF, 0x40, 0x00, 0xC0, 0xFF, 0xC0, 0xFE, 0x00, 0x02, 0x5E, 0x05, 0x2E, 0x05, 0xB1, 0x04, 0x9F, 0xFB, 0x20, 0x04, 0xE0, 0xFE, 0xE0, 0xFC, 0x40, 0x29, 0xB3, 0x36, 0x43, 0x3E, 0xDC, 0x18, 0x9F, 0xFD, 0x84, 0xF2, 0x7C, 0x0F, 0xFC, 0xF9, 0x18, 0x2F, 0x5F, 0x10, 0xA1, 0xFA, 0xFE, 0xFA, 0xDF, 0xF3, 0x1F, 0xED, 0xEF, 0x1F, 0xFF, 0xFA, 0xB0, 0xD6, 0x54, 0x08, 0x23, 0xFF, 0xFF, 0xFF, 0xFF, 0xCD, 0xCF, 0xFE, 0x3F, 0x3F, 0xFF, 0xF3, 0xF0, 0xB4, 0xF2, 0x4F, 0x0D, 0xFF, 0xFF, 0xFB, 0xFF, 0xB6, 0x71, 0xF9, 0xFF, 0xFF, 0xFF, 0x4F, 0x8E, 0xEC, 0xCD, 0x13, 0xF2, 0xFF, 0xFF, 0xFF, 0x3F, 0x7F, 0x8A, 0xFF, 0xF5, 0xFF, 0xFF, 0x80, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x03, 0x00, 0x1C, 0x00, 0x00, 0x80, 0x00, 0x80, 0x00, 0x78, 0x00, 0x00, 0x00, 0x00, 0x0A, 0x00, 0x0D, 0x00, 0x70, 0x00, 0x02, 0xE0, 0x00, 0xE0, 0x00, 0x1E, 0x00, 0x00, 0x00, 0x00, 0x26, 0x00, 0x39, 0x00, 0xC0, 0x00, 0x06, 0x40, 0x00, 0xC0, 0x00, 0x3F, 0x00, 0x00, 0x00, 0x00, 0x5D, 0x00, 0x62, 0x00, 0x80, 0x00, 0x1D, 0x3C, 0x00, 0xFC, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x33, 0x00, 0x4F, 0x01, 0x80, 0x00, 0x30, 0xAA, 0x00, 0xD6, 0x00, 0x01, 0x80, 0x28, 0x00, 0x00, 0x2C, 0x00, 0xDC, 0x01, 0x03, 0x00, 0x20, 0x5E, 0x00, 0x66, 0x00, 0x81, 0x80, 0x18, 0x00, 0x01, 0x90, 0x01, 0xF0, 0x02, 0x0F, 0x00, 0x00, 0x3A, 0x00, 0x36, 0x00, 0xC1, 0xC0, 0x08, 0x00, 0x01, 0x60, 0x01, 0xA0, 0x02, 0x1F, 0x00, 0x40, 0x06, 0x80, 0x0A, 0x80, 0xF1, 0x40, 0x04, 0x00, 0x02, 0xC2, 0x03, 0x43, 0x04, 0x3C, 0x00, 0x80, 0x23, 0x80, 0xE7, 0x80, 0x18, 0x40, 0xC0, 0x00, 0x02, 0x8B, 0x03, 0x8F, 0x04, 0x71, 0x00, 0x03, 0x51, 0x00, 0xD7, 0x80, 0x28, 0x60, 0xE0, 0x00, 0x03, 0x96, 0x03, 0x9B, 0x04, 0x6C, 0x00, 0x0F, 0xEA, 0x40, 0xDB, 0xC0, 0xB4, 0x20, 0xF0, 0x00, 0x05, 0x2F, 0x07, 0x3D, 0x08, 0xDE, 0x00, 0x13, 0xF5, 0x20, 0xBD, 0xE0, 0x7A, 0x00, 0xC8, 0x00, 0x03, 0x03, 0x05, 0x21, 0x08, 0xDA, 0x02, 0x07, 0x86, 0xE0, 0xC2, 0xA0, 0x59, 0x10, 0xE4, 0x40, 0x0D, 0x6D, 0x0B, 0x61, 0x00, 0x9E, 0x04, 0x3F, 0x52, 0xE0, 0xA2, 0xA0, 0x7D, 0x10, 0xFC, 0x40, 0x0A, 0x0D, 0x0E, 0x7D, 0x11, 0x82, 0x00, 0x3F, 0xE3, 0x20, 0x81, 0x60, 0x7E, 0x90, 0xFE, 0x00, 0x0A, 0x27, 0x0E, 0x3F, 0x11, 0xC0, 0x00, 0x7F, 0x34, 0x40, 0x92, 0x60, 0x6F, 0x98, 0xFE, 0x00, 0x06, 0x17, 0x06, 0x1F, 0x19, 0xE0, 0x00, 0x7F, 0xA8, 0x10, 0xA6, 0x30, 0x5F, 0xC8, 0xFE, 0x00, 0x0C, 0x1F, 0x0C, 0x1F, 0x13, 0xE0, 0x00, 0x3F, 0x00, 0x30, 0x0C, 0x30, 0xFF, 0xCC, 0xFC, 0x00, 0x14, 0x3C, 0x1C, 0x1C, 0x23, 0xE3, 0x00, 0x3F, 0x18, 0x10, 0x04, 0x10, 0xFF, 0xEC, 0xFC, 0x00, 0x1C, 0x05, 0x14, 0x23, 0x23, 0xFF, 0x08, 0x3E, 0xB0, 0x08, 0xCC, 0x18, 0xFF, 0xE4, 0x7C, 0x00, 0x14, 0x12, 0x1C, 0x01, 0x23, 0xFF, 0x00, 0x1F, 0x50, 0x28, 0x88, 0x38, 0xFF, 0xC4, 0xF8, 0x00, 0x0A, 0x14, 0x0E, 0x07, 0x11, 0xF8, 0x00, 0x1F, 0x90, 0x10, 0x88, 0x10, 0x7F, 0xE8, 0xF8, 0x00, 0x05, 0x1B, 0x07, 0x03, 0x18, 0xFC, 0x00, 0x1F, 0xA0, 0x10, 0x98, 0x10, 0x7F, 0xE0, 0xF8, 0x00, 0x05, 0x8E, 0x07, 0x80, 0x08, 0x5F, 0x00, 0x1F, 0x61, 0xA0, 0x19, 0xA0, 0xFA, 0x50, 0xF8, 0x00, 0x03, 0xD7, 0x03, 0xD0, 0x04, 0x2F, 0x00, 0x3F, 0xF4, 0x00, 0x0B, 0x00, 0xF8, 0xE0, 0xFC, 0x00, 0x03, 0x5D, 0x03, 0xFC, 0x00, 0x03, 0x00, 0x1F, 0xF1, 0x00, 0x0F, 0x00, 0xE0, 0x80, 0xF0, 0x00, 0x01, 0xD7, 0x01, 0xEF, 0x1E, 0x00, 0x00, 0x17, 0x4C, 0x00, 0x3C, 0x00, 0xC3, 0xF8, 0xC0, 0x00, 0x0E, 0xE9, 0x0F, 0xF7, 0xF0, 0x00, 0x00, 0x09, 0x98, 0x00, 0x78, 0x00, 0x07, 0xFF, 0x80, 0x00, 0x38, 0xF3, 0x3F, 0xFF, 0xC0, 0x00, 0x00, 0x00, 0x7F, 0x80, 0xFF, 0x80, 0x00, 0x7F, 0x00, 0x00, 0x45, 0xB6, 0x7F, 0xBE, 0x80, 0x41, 0x00, 0x00, 0xEB, 0x70, 0xEF, 0xF0, 0x10, 0x0F, 0x00, 0x00, 0x9B, 0x1E, 0xFF, 0x1E, 0x00, 0xE1, 0x00, 0x00, 0x4A, 0x9C, 0x4E, 0xFC, 0xB1, 0x03, 0x00, 0x00, 0x9B, 0x1E, 0xFF, 0x1E, 0x00, 0xE1, 0x00, 0x00, 0x4A, 0x9C, 0x4E, 0xFC, 0xB1, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00, 0x1F, 0x00, 0x1F, 0x00, 0x07, 0x68, 0x00, 0xD8, 0x00, 0xF8, 0x00, 0xB0, 0x00, 0x00, 0x5F, 0x00, 0x60, 0x00, 0x7F, 0x00, 0x3F, 0xB2, 0x00, 0xCE, 0x00, 0xFE, 0x00, 0x7C, 0x00, 0x01, 0x61, 0x01, 0x80, 0x01, 0xFF, 0x00, 0xFF, 0x48, 0x80, 0x87, 0x80, 0xFF, 0x80, 0xFF, 0x00, 0x00, 0x80, 0x01, 0x01, 0x01, 0xFF, 0x01, 0xFF, 0x9D, 0xC0, 0x02, 0x40, 0xFF, 0xC0, 0xFF, 0x80, 0x02, 0x99, 0x03, 0x00, 0x03, 0xFF, 0x01, 0xFF, 0xFF, 0x80, 0x00, 0x40, 0xFF, 0xC0, 0xFF, 0xC0, 0x05, 0x42, 0x06, 0x3C, 0x07, 0xFF, 0x03, 0xFF, 0x4F, 0x20, 0x30, 0xE0, 0xFF, 0xE0, 0xFF, 0xC0, 0x03, 0x90, 0x04, 0x60, 0x07, 0xFF, 0x07, 0xFF, 0x0A, 0x80, 0x09, 0x60, 0xF7, 0xE0, 0xFF, 0xE0, 0x02, 0xC6, 0x05, 0x1F, 0x07, 0xE6, 0x07, 0xFF, 0x39, 0x00, 0xF8, 0xE0, 0x07, 0xE0, 0xFF, 0xE0, 0x0E, 0xB3, 0x0C, 0x3F, 0x0F, 0xC3, 0x03, 0xFF, 0x70, 0xD0, 0xF0, 0x30, 0x0F, 0xF0, 0xFF, 0xE0, 0x06, 0x6B, 0x0F, 0x13, 0x0D, 0xFD, 0x0B, 0xFF, 0x26, 0x40, 0x98, 0xB0, 0x7F, 0xF0, 0xFF, 0xF0, 0x01, 0x0E, 0x09, 0x03, 0x0E, 0xFC, 0x0F, 0xFF, 0x8C, 0x20, 0xB0, 0x50, 0x7F, 0xF0, 0xFF, 0xF0, 0x0E, 0xB8, 0x06, 0x99, 0x09, 0x52, 0x0F, 0xE7, 0xDC, 0x00, 0x98, 0x10, 0x4B, 0xF0, 0xE7, 0xF0, 0x07, 0xB3, 0x0E, 0xF3, 0x09, 0x0C, 0x0F, 0xFF, 0xFD, 0x80, 0x8C, 0x10, 0x73, 0xF0, 0xFF, 0xF0, 0x09, 0x0F, 0x00, 0x7F, 0x0F, 0x80, 0x0F, 0xFF, 0xE9, 0x00, 0x88, 0x90, 0x77, 0xF0, 0xFF, 0xF0, 0x0D, 0xE6, 0x07, 0x7F, 0x0E, 0xA0, 0x0B, 0xFF, 0xAA, 0x30, 0x89, 0x30, 0x77, 0xF0, 0xFF, 0xC0, 0x08, 0xB2, 0x07, 0x3F, 0x0F, 0xD0, 0x0F, 0xFF, 0x96, 0x80, 0x91, 0xE0, 0x6F, 0xE0, 0xFF, 0x60, 0x0E, 0xD6, 0x0B, 0x1E, 0x0F, 0xE1, 0x05, 0xFF, 0x44, 0xC0, 0x03, 0xE0, 0xFF, 0xE0, 0xFF, 0x20, 0x05, 0x27, 0x03, 0xC0, 0x07, 0xFF, 0x06, 0xFF, 0x19, 0xA0, 0xE7, 0xC0, 0xFF, 0xE0, 0xFE, 0x60, 0x02, 0x5C, 0x01, 0xA3, 0x07, 0xFF, 0x07, 0xFF, 0x01, 0x40, 0xFF, 0xA0, 0xFF, 0xE0, 0xFE, 0xE0, 0x07, 0xAB, 0x06, 0xD7, 0x07, 0xFF, 0x01, 0x7C, 0xC3, 0x60, 0xFF, 0xA0, 0xFF, 0xE0, 0x3C, 0xC0, 0x01, 0x16, 0x00, 0xE9, 0x01, 0xFF, 0x01, 0xFF, 0x62, 0x80, 0x9F, 0xC0, 0xFF, 0xC0, 0xFD, 0x40, 0x01, 0xE5, 0x01, 0x7A, 0x01, 0xFF, 0x00, 0x9F, 0xC6, 0x40, 0x3F, 0x40, 0xFF, 0x40, 0xF9, 0x00, 0x00, 0x38, 0x00, 0xBF, 0x00, 0xBF, 0x00, 0x87, 0x1E, 0x00, 0xFF, 0x00, 0xFF, 0x00, 0xE1, 0x00, 0x00, 0x8E, 0x00, 0x9F, 0x00, 0xBF, 0x00, 0x31, 0x73, 0x00, 0xFF, 0x00, 0xFF, 0x00, 0x8C, 0x00, 0x00, 0x2B, 0x00, 0x27, 0x00, 0x5F, 0x00, 0x7C, 0xD8, 0x00, 0xE6, 0x00, 0xFE, 0x00, 0x3E, 0x00, 0x00, 0xFB, 0x00, 0xF8, 0x01, 0x07, 0x00, 0x7F, 0xFE, 0x00, 0x02, 0x00, 0xFD, 0x00, 0xFC, 0x00, 0x17, 0xBF, 0x19, 0xFF, 0x1E, 0x00, 0x0E, 0x3F, 0x7F, 0x48, 0x07, 0xB8, 0xF8, 0xF8, 0xF8, 0xF0, 0x91, 0x1B, 0xC1, 0x67, 0xDE, 0x80, 0x7F, 0x9B, 0x9F, 0xF7, 0xFC, 0x0B, 0x03, 0xFB, 0x83, 0xFC, 0x67, 0x07, 0x87, 0x08, 0xE8, 0xF0, 0xFF, 0xF7, 0x38, 0x79, 0xE0, 0x07, 0x1F, 0xF7, 0x1F, 0xFE, 0xBA, 0x49, 0x0A, 0x09, 0xE5, 0xF6, 0xFF, 0xFF, 0x14, 0x80, 0x04, 0x87, 0xFB, 0x77, 0xFF, 0xFF, 0x5C, 0xE0, 0x44, 0x00, 0xB3, 0xFF, 0xFF, 0xFF, 0xB5, 0x6A, 0x04, 0x65, 0xFB, 0x8F, 0xFF, 0xFF, 0x6C, 0xE1, 0x74, 0x00, 0x93, 0xFF, 0xFF, 0xFF, 0xB5, 0x76, 0x04, 0x69, 0xFB, 0x8F, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1B, 0x00, 0x1F, 0x00, 0x1F, 0x00, 0x04, 0x98, 0x00, 0xF8, 0x00, 0xF8, 0x00, 0x60, 0x00, 0x00, 0x48, 0x00, 0x77, 0x00, 0x7F, 0x00, 0x3F, 0x22, 0x00, 0xDE, 0x00, 0xFE, 0x00, 0xFC, 0x00, 0x00, 0xBD, 0x00, 0xC3, 0x00, 0xFF, 0x00, 0x7E, 0x79, 0x00, 0x87, 0x00, 0xFF, 0x00, 0xFE, 0x00, 0x00, 0x62, 0x00, 0x81, 0x00, 0xFF, 0x00, 0xFF, 0x5C, 0x00, 0x83, 0x00, 0xFF, 0x00, 0xFF, 0x00, 0x01, 0xD9, 0x01, 0x20, 0x01, 0xFF, 0x00, 0xFF, 0x66, 0x80, 0x99, 0x80, 0xFF, 0x80, 0xFF, 0x00, 0x00, 0xBF, 0x01, 0x40, 0x01, 0xFF, 0x01, 0xFF, 0xDF, 0x00, 0x20, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x03, 0xE6, 0x02, 0x05, 0x03, 0xFB, 0x01, 0xFF, 0x73, 0x40, 0x80, 0xC0, 0xFF, 0xC0, 0xFF, 0x80, 0x01, 0xC7, 0x02, 0x1F, 0x03, 0xE7, 0x03, 0xFF, 0x3D, 0x00, 0xFC, 0xC0, 0x03, 0xC0, 0xFF, 0xC0, 0x03, 0xB3, 0x00, 0x3F, 0x03, 0xC3, 0x03, 0xE7, 0x58, 0x00, 0xFC, 0xC0, 0x03, 0xC0, 0xC3, 0xC0, 0x01, 0x7B, 0x02, 0x1F, 0x03, 0xE1, 0x03, 0xE3, 0x06, 0x00, 0xCE, 0xC0, 0x39, 0xC0, 0x89, 0xC0, 0x00, 0x0E, 0x01, 0x07, 0x03, 0xF8, 0x03, 0xFB, 0xCC, 0x40, 0xF1, 0x80, 0x3E, 0xC0, 0xBE, 0xC0, 0x01, 0x6F, 0x01, 0x1D, 0x02, 0xFE, 0x03, 0xF3, 0xF6, 0x40, 0xB8, 0x00, 0x7F, 0xC0, 0xCF, 0xC0, 0x02, 0xA3, 0x02, 0x81, 0x01, 0x5A, 0x03, 0xE7, 0x84, 0x00, 0xC0, 0x00, 0x5B, 0xC0, 0xE7, 0xC0, 0x03, 0xAD, 0x02, 0xE1, 0x01, 0x1E, 0x03, 0xFF, 0x53, 0x80, 0xA2, 0x00, 0x7D, 0xC0, 0xFF, 0xC0, 0x01, 0x0F, 0x00, 0x7F, 0x03, 0x80, 0x03, 0xFF, 0xE9, 0x00, 0x88, 0x80, 0x77, 0xC0, 0xFF, 0xC0, 0x01, 0x26, 0x03, 0x7F, 0x02, 0xA0, 0x03, 0xFF, 0xAB, 0x00, 0x88, 0x40, 0x77, 0xC0, 0xFF, 0xC0, 0x02, 0x72, 0x02, 0x7F, 0x03, 0xB0, 0x01, 0xFF, 0x96, 0x40, 0x91, 0x40, 0x6F, 0xC0, 0xFF, 0x80, 0x00, 0xD6, 0x01, 0x7E, 0x01, 0x91, 0x01, 0xFF, 0x46, 0x00, 0x01, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x01, 0x1E, 0x01, 0xBE, 0x01, 0xD1, 0x00, 0xFF, 0xA4, 0x80, 0x23, 0x80, 0xDF, 0x80, 0xFF, 0x00, 0x00, 0xA9, 0x00, 0xB9, 0x00, 0xC6, 0x00, 0x7F, 0x95, 0x00, 0x93, 0x00, 0x6F, 0x00, 0xFE, 0x00, 0x00, 0x74, 0x00, 0x33, 0x00, 0x4F, 0x00, 0x7F, 0x24, 0x00, 0xC2, 0x00, 0xFE, 0x00, 0xFE, 0x00, 0x00, 0x19, 0x00, 0x58, 0x00, 0x67, 0x00, 0x7F, 0x94, 0x00, 0x12, 0x00, 0xEE, 0x00, 0xFE, 0x00, 0x00, 0x60, 0x00, 0x4F, 0x00, 0x70, 0x00, 0x3F, 0xEE, 0x00, 0xE2, 0x00, 0x1E, 0x00, 0xFC, 0x00, 0x00, 0x22, 0x00, 0x06, 0x00, 0x39, 0x00, 0x3F, 0x48, 0x00, 0x44, 0x00, 0xBC, 0x00, 0xFC, 0x00, 0x00, 0x19, 0x00, 0x00, 0x00, 0x3F, 0x00, 0x3F, 0x90, 0x00, 0x0C, 0x00, 0xFC, 0x00, 0xFC, 0x00, 0x00, 0xAF, 0x00, 0xA0, 0x00, 0x5F, 0x00, 0xFF, 0xF8, 0x00, 0x04, 0x00, 0xFE, 0x00, 0xFE, 0x00, 0x01, 0x3B, 0x01, 0xF8, 0x00, 0x07, 0x01, 0xFF, 0xFE, 0x00, 0x0E, 0x00, 0xF1, 0x00, 0xFF, 0x00, 0x0E, 0xFF, 0x11, 0xFF, 0x1E, 0xF0, 0x1F, 0xFF, 0x6B, 0x40, 0x3F, 0xB8, 0xC8, 0xF8, 0xFF, 0xF8, 0x70, 0xFF, 0x8F, 0xFF, 0xFE, 0xFC, 0xF1, 0xFF, 0x9D, 0xF0, 0xBF, 0x0F, 0x5C, 0xFF, 0xFF, 0xFF, 0xCE, 0x5C, 0x33, 0xE6, 0xFB, 0x5D, 0xC2, 0xEF, 0xA8, 0xFC, 0xEF, 0x03, 0x39, 0xFF, 0xFE, 0xFF, 0xBE, 0x1A, 0x45, 0xE6, 0xE5, 0x9B, 0x84, 0x7F, 0xD9, 0xC6, 0xEE, 0x21, 0x5B, 0xFF, 0xFD, 0x9F, 0x7E, 0x1A, 0x81, 0x47, 0xDB, 0xBE, 0x00, 0xFB, 0x73, 0x72, 0xCC, 0x89, 0x77, 0xBF, 0xFB, 0x07, 0xF6, 0x7B, 0x09, 0x07, 0x9B, 0xFF, 0x00, 0xFB, 0xFF, 0x72, 0xC0, 0x8D, 0xFF, 0x9F, 0xFF, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x04, 0x00, 0x1B, 0x00, 0x00, 0x60, 0x00, 0x60, 0x00, 0x98, 0x00, 0x00, 0x00, 0x00, 0x37, 0x00, 0x3F, 0x00, 0x40, 0x00, 0x00, 0xDC, 0x00, 0xFC, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x42, 0x00, 0x7E, 0x00, 0x81, 0x00, 0x00, 0x86, 0x00, 0xFE, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x9D, 0x00, 0xE3, 0x00, 0x00, 0x00, 0x1C, 0xA3, 0x00, 0xDF, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x26, 0x00, 0xF9, 0x01, 0x00, 0x00, 0x06, 0x99, 0x00, 0xFF, 0x00, 0x00, 0x80, 0x00, 0x00, 0x01, 0x40, 0x01, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x20, 0x80, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x25, 0x01, 0xC7, 0x02, 0x38, 0x00, 0x3C, 0xB2, 0x80, 0xC1, 0x80, 0x3E, 0x40, 0x3E, 0x00, 0x02, 0xC6, 0x03, 0x1F, 0x00, 0xE6, 0x00, 0xFF, 0x39, 0xC0, 0xF8, 0xC0, 0x07, 0x00, 0xFF, 0x00, 0x00, 0xB3, 0x03, 0x3F, 0x00, 0xC3, 0x00, 0xFF, 0x70, 0xC0, 0xF0, 0xC0, 0x0F, 0x00, 0xFF, 0x00, 0x00, 0x6B, 0x03, 0x13, 0x02, 0xFD, 0x02, 0xFF, 0x26, 0x80, 0x98, 0xC0, 0x7F, 0x40, 0xFF, 0x40, 0x01, 0x0E, 0x01, 0x03, 0x02, 0xFC, 0x02, 0xFF, 0x8C, 0xC0, 0xB0, 0x80, 0x7F, 0x40, 0xFF, 0x40, 0x02, 0x38, 0x02, 0x19, 0x01, 0xD2, 0x03, 0xE7, 0xDC, 0x00, 0x98, 0x00, 0x4B, 0xC0, 0xE7, 0xC0, 0x03, 0xB3, 0x02, 0xF3, 0x01, 0x0C, 0x03, 0xFF, 0xFD, 0x80, 0x8C, 0x00, 0x73, 0xC0, 0xFF, 0xC0, 0x01, 0x0F, 0x00, 0x7F, 0x03, 0x80, 0x03, 0xFF, 0xE9, 0x00, 0x88, 0x80, 0x77, 0xC0, 0xFF, 0xC0, 0x01, 0x26, 0x03, 0x7F, 0x02, 0xA0, 0x03, 0xFF, 0xAB, 0x00, 0x88, 0x40, 0x77, 0xC0, 0xFF, 0xC0, 0x02, 0x72, 0x02, 0x7F, 0x03, 0xB0, 0x01, 0xFF, 0x96, 0x40, 0x91, 0x40, 0x6F, 0xC0, 0xFF, 0x80, 0x00, 0xD6, 0x01, 0x7E, 0x01, 0x91, 0x01, 0xFF, 0x46, 0x00, 0x01, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x01, 0x1C, 0x01, 0xBF, 0x01, 0xD0, 0x00, 0xFC, 0xF4, 0x80, 0xC3, 0x80, 0x3F, 0x80, 0x3F, 0x00, 0x01, 0xA3, 0x01, 0xBF, 0x00, 0xC0, 0x00, 0x70, 0xFD, 0x80, 0xF3, 0x80, 0x0F, 0x00, 0x0E, 0x00, 0x01, 0xE4, 0x01, 0xBF, 0x00, 0x43, 0x00, 0x63, 0x39, 0x80, 0xFF, 0x80, 0xC6, 0x00, 0xC6, 0x00, 0x00, 0x11, 0x00, 0xFC, 0x01, 0x43, 0x00, 0x43, 0x89, 0x00, 0x3B, 0x00, 0xC6, 0x80, 0xC2, 0x00, 0x00, 0xFB, 0x00, 0xFF, 0x00, 0x40, 0x00, 0x00, 0xDB, 0x00, 0xFB, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x27, 0x00, 0xF8, 0x00, 0x20, 0xE0, 0x00, 0xE4, 0x00, 0x1F, 0x00, 0x04, 0x00, 0x00, 0x01, 0x00, 0x11, 0x00, 0x3E, 0x00, 0x30, 0x80, 0x00, 0x8C, 0x00, 0x7C, 0x00, 0x0C, 0x00, 0x00, 0x28, 0x00, 0x24, 0x00, 0x5F, 0x00, 0x7C, 0x08, 0x00, 0x36, 0x00, 0xFE, 0x00, 0x3E, 0x00, 0x00, 0x7B, 0x00, 0x78, 0x00, 0x87, 0x00, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0xFF, 0x00, 0xFF, 0x00, 0x0B, 0x7F, 0x0D, 0xBF, 0x0E, 0x00, 0x06, 0x7F, 0x7E, 0x50, 0x01, 0xB0, 0xFE, 0x70, 0xFE, 0x60, 0xA0, 0xBF, 0xC0, 0xDF, 0xFF, 0x00, 0x7F, 0x3F, 0xFC, 0xFD, 0xFB, 0x03, 0x00, 0xFF, 0xFC, 0xFE, 0x8C, 0x57, 0x0C, 0x6B, 0xF3, 0x80, 0xFF, 0x97, 0xC1, 0x70, 0xFE, 0x0F, 0x01, 0xFF, 0xC1, 0xFF, 0x33, 0x2C, 0x00, 0x33, 0xFF, 0xC0, 0xFF, 0xCC, 0xA0, 0xFC, 0x5C, 0x03, 0x03, 0xFF, 0xA3, 0xFF, 0x9D, 0x17, 0x82, 0x18, 0x7F, 0xE0, 0x7F, 0xE7, 0x61, 0x9F, 0x98, 0x01, 0x07, 0xFE, 0x67, 0xFE, 0xB0, 0xC9, 0x8F, 0x0E, 0x7F, 0xF0, 0x7F, 0xF1, 0x83, 0x4B, 0x70, 0x41, 0x0F, 0xBE, 0x8F, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x14, 0x00, 0x1F, 0x00, 0x20, 0x00, 0x00, 0xD8, 0x00, 0xFC, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x27, 0x00, 0x20, 0x00, 0x5E, 0x00, 0x04, 0xA6, 0x00, 0x56, 0x00, 0xF9, 0x00, 0x30, 0x00, 0x00, 0x0D, 0x00, 0x43, 0x00, 0x3E, 0x00, 0x0E, 0x53, 0x00, 0x6B, 0x00, 0xBC, 0x00, 0x38, 0x00, 0x00, 0x13, 0x00, 0x13, 0x00, 0x6C, 0x00, 0x00, 0xF1, 0x00, 0xF1, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x2C, 0x00, 0x3F, 0x00, 0xC0, 0x00, 0x00, 0xBA, 0x00, 0xFA, 0x00, 0x05, 0x80, 0x00, 0x00, 0x00, 0xF5, 0x00, 0xF3, 0x00, 0x0C, 0x00, 0x04, 0xD6, 0x80, 0xEE, 0x80, 0x19, 0x00, 0x18, 0x00, 0x01, 0x4A, 0x01, 0x5E, 0x01, 0xB1, 0x00, 0x1F, 0x25, 0x00, 0x23, 0x00, 0xDE, 0x80, 0xFE, 0x00, 0x00, 0xDF, 0x00, 0xFF, 0x01, 0x2F, 0x00, 0x3F, 0x1D, 0x00, 0xFB, 0x00, 0x06, 0xC0, 0xFE, 0x00, 0x00, 0xA7, 0x00, 0x9F, 0x01, 0x67, 0x00, 0x3F, 0x3E, 0x80, 0xFD, 0x80, 0x03, 0x40, 0xFF, 0x00, 0x00, 0xA6, 0x00, 0xFF, 0x01, 0x46, 0x00, 0x7F, 0x38, 0x00, 0xF9, 0x00, 0x07, 0xC0, 0xFF, 0x00, 0x02, 0xB3, 0x03, 0xBF, 0x03, 0x43, 0x01, 0x7F, 0x70, 0xC0, 0xF0, 0xC0, 0x0F, 0x40, 0xFF, 0x00, 0x01, 0xEB, 0x03, 0x93, 0x02, 0x7D, 0x03, 0x7F, 0x26, 0x80, 0x98, 0xC0, 0x7F, 0x40, 0xFF, 0x40, 0x01, 0x8E, 0x01, 0x83, 0x02, 0x7C, 0x03, 0x7F, 0x8C, 0x40, 0xB0, 0x00, 0x7F, 0xC0, 0xFF, 0x40, 0x02, 0xB8, 0x02, 0x99, 0x01, 0x52, 0x03, 0xE7, 0xDC, 0x00, 0x98, 0x00, 0x4B, 0xC0, 0xE7, 0xC0, 0x03, 0xB3, 0x02, 0xF3, 0x01, 0x0C, 0x03, 0xFF, 0xFD, 0x80, 0x8C, 0x00, 0x73, 0xC0, 0xFF, 0xC0, 0x01, 0x0F, 0x00, 0x7F, 0x03, 0x80, 0x03, 0xFF, 0xE9, 0x00, 0x88, 0x80, 0x77, 0xC0, 0xFF, 0xC0, 0x01, 0x26, 0x03, 0x7F, 0x02, 0xA0, 0x03, 0xFF, 0xAB, 0x00, 0x88, 0x40, 0x77, 0xC0, 0xFF, 0xC0, 0x02, 0x72, 0x02, 0x7F, 0x03, 0xB0, 0x01, 0xFF, 0x96, 0x40, 0x91, 0x40, 0x6F, 0xC0, 0xFF, 0x80, 0x00, 0xD6, 0x00, 0x7E, 0x01, 0x91, 0x00, 0xFF, 0x46, 0x00, 0x01, 0x80, 0xFF, 0x80, 0xFF, 0x80, 0x01, 0x16, 0x01, 0x36, 0x00, 0xD9, 0x00, 0x78, 0x64, 0x00, 0x63, 0x00, 0x9F, 0x80, 0x1F, 0x00, 0x00, 0xEC, 0x00, 0xFF, 0x01, 0x43, 0x00, 0x23, 0x34, 0x80, 0xFA, 0x80, 0xC7, 0x00, 0xC6, 0x00, 0x00, 0x2C, 0x00, 0xB3, 0x00, 0x4F, 0x00, 0x2F, 0x3D, 0x00, 0xCB, 0x00, 0xF6, 0x80, 0xF6, 0x00, 0x00, 0x79, 0x00, 0xF8, 0x00, 0x27, 0x00, 0x1F, 0x95, 0x00, 0x11, 0x00, 0xEE, 0x00, 0xFC, 0x00, 0x00, 0x80, 0x00, 0xCF, 0x00, 0x30, 0x00, 0x1F, 0xEE, 0x00, 0xE3, 0x00, 0x1C, 0x00, 0xFC, 0x00, 0x00, 0x82, 0x00, 0xC6, 0x01, 0x39, 0x00, 0x1F, 0x4A, 0x00, 0x47, 0x00, 0xBC, 0x80, 0xFC, 0x00, 0x01, 0x29, 0x01, 0xE0, 0x00, 0x1F, 0x00, 0x0F, 0x90, 0x80, 0x0D, 0x80, 0xFE, 0x00, 0xFC, 0x00, 0x01, 0x5F, 0x01, 0xD0, 0x00, 0x2F, 0x00, 0x0F, 0xF9, 0x80, 0x07, 0x80, 0xFE, 0x40, 0xFE, 0x00, 0x01, 0x6B, 0x01, 0xE8, 0x00, 0x17, 0x00, 0x0F, 0xFF, 0x40, 0x00, 0xC0, 0xFF, 0x00, 0xFF, 0x00, 0x08, 0x87, 0x0D, 0xB7, 0x0E, 0x48, 0x04, 0x07, 0x7E, 0x50, 0x01, 0xD0, 0xFE, 0x30, 0xFE, 0x00, 0x9F, 0x27, 0xDF, 0xB7, 0xFC, 0x48, 0x7C, 0x07, 0xF9, 0x31, 0xFF, 0x73, 0x00, 0x8F, 0xF8, 0x46, 0xFC, 0x33, 0xFE, 0xF7, 0xFD, 0x08, 0xFC, 0x03, 0xFE, 0xAF, 0xFE, 0xEF, 0x01, 0x90, 0xC0, 0xCF, 0xCC, 0xD3, 0xFF, 0xFF, 0xCC, 0xC0, 0xFF, 0xC0, 0x5B, 0x03, 0xFF, 0xFF, 0x03, 0x00, 0x03, 0xFF, 0x62, 0xE8, 0xFF, 0xFF, 0x60, 0xE0, 0x7F, 0xE0, 0x96, 0x60, 0xFF, 0xFF, 0x06, 0x60, 0x07, 0xFE, 0xCF, 0x36, 0xFF, 0xFF, 0x40, 0x30, 0x7F, 0xF0, 0x6C, 0xF5, 0xFF, 0xFF, 0x0C, 0xF4, 0x0F, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x29, 0x00, 0x36, 0x00, 0x3F, 0x00, 0x19, 0x48, 0x00, 0x34, 0x00, 0x7C, 0x00, 0x4C, 0x00, 0x00, 0xAE, 0x00, 0xD1, 0x00, 0xFD, 0x00, 0x60, 0x34, 0x00, 0xCA, 0x00, 0xFE, 0x00, 0x06, 0x00, 0x00, 0x5F, 0x00, 0xAC, 0x00, 0xED, 0x00, 0xCC, 0x7A, 0x00, 0xB5, 0x00, 0xB7, 0x00, 0x33, 0x00, 0x01, 0xBF, 0x01, 0x50, 0x01, 0xD1, 0x00, 0x90, 0xFD, 0x00, 0x42, 0x00, 0x47, 0x00, 0x41, 0x00, 0x00, 0x7F, 0x01, 0xA2, 0x01, 0xFC, 0x01, 0x22, 0xB6, 0x80, 0x49, 0x80, 0xF9, 0x80, 0x00, 0x00, 0x01, 0x6F, 0x00, 0x90, 0x01, 0x9F, 0x01, 0x0C, 0x2E, 0x00, 0x93, 0x80, 0x7B, 0x80, 0xCA, 0x80, 0x02, 0xF1, 0x03, 0x00, 0x03, 0xBF, 0x00, 0x1E, 0x2F, 0x80, 0xC2, 0x00, 0x3F, 0x80, 0xDB, 0x80, 0x02, 0xD6, 0x03, 0x26, 0x03, 0xBF, 0x00, 0x1F, 0xB7, 0x00, 0x58, 0x80, 0xA9, 0x80, 0x59, 0x00, 0x00, 0xE6, 0x03, 0x0F, 0x03, 0xF6, 0x00, 0x3F, 0x3A, 0x00, 0xFC, 0x00, 0x07, 0x80, 0xF9, 0x80, 0x00, 0xD3, 0x03, 0x1F, 0x03, 0x63, 0x00, 0x3F, 0x77, 0xC0, 0xF0, 0x40, 0x0F, 0x40, 0xFC, 0x00, 0x02, 0xEB, 0x01, 0x13, 0x03, 0xFD, 0x02, 0x7F, 0x25, 0x80, 0x98, 0x40, 0x7F, 0xC0, 0xFF, 0x00, 0x05, 0x8E, 0x04, 0x43, 0x06, 0xFC, 0x02, 0x7F, 0x8D, 0xC0, 0xB0, 0x00, 0x7F, 0xC0, 0xFF, 0x00, 0x03, 0xB8, 0x0C, 0x59, 0x0C, 0xD2, 0x08, 0x67, 0xDC, 0xA0, 0x99, 0x40, 0x4B, 0xE0, 0xE7, 0x20, 0x07, 0x33, 0x1A, 0x33, 0x1F, 0xCC, 0x12, 0xFF, 0xFD, 0x00, 0x8C, 0xE0, 0x73, 0xE0, 0xFF, 0x40, 0x1E, 0x8F, 0x03, 0x7F, 0x1B, 0x80, 0x12, 0xFF, 0xEA, 0x00, 0x89, 0xF0, 0x77, 0xF0, 0xFE, 0x50, 0x0F, 0xA6, 0x14, 0x7F, 0x15, 0xA0, 0x05, 0xFF, 0xAA, 0x60, 0x89, 0x90, 0x77, 0xF0, 0xFE, 0x40, 0x1D, 0xF2, 0x26, 0xFF, 0x37, 0xB0, 0x25, 0x7F, 0x95, 0x20, 0x93, 0xD8, 0x6F, 0xF8, 0xFE, 0x08, 0x2D, 0xD6, 0x1E, 0x7E, 0x3F, 0x91, 0x2D, 0xFF, 0x47, 0x38, 0x01, 0xC0, 0xFF, 0xF8, 0xFE, 0xA8, 0x1E, 0x1E, 0x29, 0xBE, 0x3B, 0xD1, 0x18, 0xFF, 0xA4, 0xB0, 0x23, 0xC8, 0xDF, 0xF8, 0xFF, 0x60, 0x2A, 0xA9, 0x15, 0x39, 0x35, 0xC6, 0x30, 0xFF, 0x95, 0x78, 0x93, 0x80, 0x6F, 0xF0, 0xFE, 0xF0, 0x1B, 0x74, 0x26, 0xB3, 0x3F, 0xCF, 0x32, 0x7F, 0x26, 0x98, 0xC3, 0x60, 0xFF, 0xF8, 0xFD, 0x90, 0x36, 0xD9, 0x0B, 0x18, 0x2F, 0xE7, 0x22, 0x7F, 0x97, 0x68, 0x12, 0x90, 0xEF, 0xF8, 0xFD, 0x08, 0x1E, 0xA0, 0x21, 0x4F, 0x3B, 0x70, 0x08, 0x3F, 0xED, 0x50, 0xE2, 0xA8, 0x1F, 0xB8, 0xFF, 0x18, 0x3C, 0xE2, 0x03, 0x06, 0x3B, 0xF9, 0x30, 0x3F, 0x4A, 0xE0, 0x45, 0x18, 0xBF, 0x98, 0xFE, 0x08, 0x1D, 0x59, 0x22, 0xA0, 0x37, 0xBF, 0x31, 0x1F, 0x92, 0x38, 0x0D, 0xC0, 0xFF, 0xD8, 0xFE, 0x18, 0x3A, 0x6F, 0x25, 0x80, 0x3F, 0xFF, 0x12, 0x1F, 0xF9, 0xB8, 0x06, 0x40, 0xFF, 0xD8, 0xFC, 0x88, 0x1D, 0x3B, 0x02, 0xD8, 0x0E, 0xC7, 0x04, 0x1F, 0xFD, 0xE8, 0x02, 0x10, 0xFF, 0xF8, 0xFC, 0xC8, 0x0D, 0x8F, 0x12, 0x4F, 0x1F, 0x70, 0x0C, 0x3F, 0x7F, 0x60, 0x00, 0x98, 0xFF, 0xF8, 0xFE, 0x48, 0x52, 0xA3, 0x6D, 0x43, 0x9F, 0x44, 0x1E, 0x3F, 0xF0, 0xFC, 0xFF, 0x0C, 0x01, 0xDB, 0xF0, 0x50, 0xAD, 0xB1, 0xD5, 0x41, 0x17, 0x42, 0x3B, 0x3F, 0xE6, 0xD2, 0x99, 0x2E, 0x01, 0xF1, 0xE6, 0x50, 0x47, 0x35, 0x80, 0xC8, 0x00, 0x81, 0x7C, 0x37, 0xF3, 0xE1, 0xB8, 0x1F, 0x00, 0xF0, 0xC7, 0x70, 0x9A, 0x11, 0x03, 0xEC, 0x01, 0x01, 0xFE, 0x13, 0xAA, 0x5D, 0xF1, 0xA3, 0x00, 0xE0, 0x8E, 0x7C, 0x9B, 0x19, 0x00, 0xE4, 0x00, 0x01, 0xFF, 0x1B, 0xEA, 0x9D, 0xB1, 0x43, 0x00, 0xC0, 0xCE, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x0B, 0x00, 0x0B, 0x00, 0x14, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x3A, 0x00, 0x3B, 0x00, 0x44, 0x00, 0x00, 0xC0, 0x00, 0xC0, 0x00, 0x38, 0x00, 0x00, 0x00, 0x00, 0xCD, 0x00, 0xFE, 0x01, 0x00, 0x00, 0x01, 0x30, 0x00, 0xF0, 0x00, 0x0E, 0x00, 0x00, 0x00, 0x01, 0x95, 0x01, 0xEE, 0x02, 0x00, 0x00, 0x11, 0xCC, 0x00, 0x3C, 0x00, 0x02, 0x00, 0xC0, 0x00, 0x01, 0x4E, 0x01, 0xBF, 0x02, 0x00, 0x00, 0x40, 0x58, 0x00, 0xB8, 0x00, 0x07, 0x00, 0x40, 0x00, 0x03, 0x56, 0x03, 0xBB, 0x04, 0x0C, 0x00, 0x4C, 0x92, 0x00, 0xF2, 0x00, 0x0D, 0x80, 0x00, 0x00, 0x02, 0xAE, 0x03, 0x75, 0x04, 0x1E, 0x00, 0x9E, 0x4B, 0x00, 0xFB, 0x00, 0x04, 0x80, 0x00, 0x00, 0x02, 0x9F, 0x03, 0x6E, 0x04, 0x3F, 0x00, 0xBF, 0x05, 0x80, 0xFF, 0x80, 0x00, 0x40, 0x00, 0x00, 0x06, 0x47, 0x07, 0xFF, 0x00, 0x27, 0x00, 0x3F, 0xB6, 0x80, 0x7F, 0x80, 0x80, 0x40, 0x80, 0x00, 0x05, 0x66, 0x06, 0xDF, 0x08, 0x26, 0x01, 0x3F, 0x72, 0xC0, 0x9F, 0xC0, 0x60, 0x20, 0xE0, 0x00, 0x08, 0xF3, 0x0F, 0xBF, 0x00, 0x43, 0x00, 0x7F, 0x78, 0x40, 0xEF, 0xC0, 0x10, 0x20, 0xF0, 0x00, 0x0D, 0xAB, 0x0F, 0xD3, 0x00, 0x7D, 0x00, 0x7F, 0x2E, 0x20, 0x97, 0xE0, 0x78, 0x00, 0xF8, 0x00, 0x06, 0x0E, 0x07, 0x83, 0x09, 0xFC, 0x01, 0xFF, 0x8F, 0xA0, 0xB0, 0xE0, 0x7F, 0x00, 0xFF, 0x00, 0x07, 0xB8, 0x06, 0x99, 0x09, 0x52, 0x01, 0xE7, 0xDC, 0xE0, 0x98, 0x60, 0x4B, 0x80, 0xE7, 0x80, 0x07, 0xB3, 0x06, 0xF3, 0x09, 0x0C, 0x01, 0xFF, 0xFD, 0xA0, 0x8C, 0x20, 0x73, 0xC0, 0xFF, 0x80, 0x0F, 0x0F, 0x0C, 0x7F, 0x03, 0x80, 0x03, 0xFF, 0xE9, 0x00, 0x88, 0x80, 0x77, 0xE0, 0xFF, 0x80, 0x09, 0x26, 0x0F, 0x7F, 0x06, 0xA0, 0x07, 0xFF, 0xAB, 0x00, 0x88, 0x80, 0x77, 0xE0, 0xFF, 0x80, 0x06, 0x72, 0x06, 0x7F, 0x0F, 0xB0, 0x01, 0xFF, 0x96, 0x80, 0x91, 0x80, 0x6F, 0xC0, 0xFF, 0x00, 0x00, 0xD6, 0x03, 0x7E, 0x0F, 0x91, 0x03, 0xFF, 0x46, 0x00, 0x01, 0x00, 0xFF, 0xC0, 0xFF, 0x00, 0x03, 0x16, 0x0B, 0xB6, 0x07, 0xD9, 0x00, 0xF8, 0x65, 0x80, 0x63, 0x80, 0x9F, 0x40, 0x1E, 0x00, 0x05, 0xAC, 0x0D, 0xBF, 0x03, 0xC3, 0x00, 0x63, 0x36, 0x00, 0xFA, 0x00, 0xC7, 0xC0, 0xC4, 0x00, 0x04, 0x6C, 0x04, 0x33, 0x0B, 0x4F, 0x00, 0x6F, 0x3D, 0x00, 0xC9, 0x00, 0xF6, 0xC0, 0xF4, 0x00, 0x02, 0x19, 0x06, 0xD8, 0x01, 0xE7, 0x00, 0xFF, 0x95, 0x00, 0x11, 0x00, 0xEE, 0x80, 0xFC, 0x00, 0x02, 0xE0, 0x02, 0xCF, 0x0D, 0xF0, 0x00, 0x3F, 0xED, 0x80, 0xE5, 0x80, 0x1E, 0x40, 0xF8, 0x00, 0x06, 0x22, 0x06, 0x06, 0x01, 0xB9, 0x00, 0x3F, 0x4B, 0x80, 0x43, 0x80, 0xBC, 0x40, 0xF8, 0x00, 0x03, 0x19, 0x07, 0x00, 0x08, 0xBF, 0x00, 0x3F, 0x91, 0x00, 0x0D, 0x00, 0xFE, 0x80, 0xFC, 0x00, 0x01, 0x2F, 0x03, 0x20, 0x04, 0x5F, 0x00, 0x7F, 0xF8, 0x00, 0x06, 0x00, 0xFF, 0x00, 0xFE, 0x00, 0x00, 0x3B, 0x00, 0xF8, 0x00, 0x07, 0x00, 0x3F, 0xFE, 0x00, 0x00, 0x00, 0xFF, 0x00, 0xFE, 0x00, 0x00, 0xCF, 0x03, 0x3F, 0x00, 0x00, 0x00, 0xCF, 0x7E, 0x00, 0x02, 0x00, 0xFD, 0xC0, 0xFC, 0x00, 0x12, 0xAD, 0x1F, 0x53, 0x20, 0x00, 0x00, 0xAD, 0xE3, 0x00, 0xFF, 0x00, 0x00, 0xFC, 0xE0, 0x00, 0xD6, 0xB1, 0x39, 0xCE, 0x00, 0x00, 0xC6, 0x30, 0x8C, 0xE0, 0x7C, 0xE0, 0x43, 0x1F, 0x00, 0x00, 0x29, 0xAB, 0xDE, 0x75, 0x00, 0x01, 0x21, 0x89, 0xC2, 0x30, 0xA3, 0xF0, 0xBC, 0x0F, 0x80, 0x00, 0x4B, 0x07, 0xFB, 0xFC, 0x04, 0x00, 0x00, 0x00, 0xC9, 0x8E, 0xAF, 0x8E, 0xB0, 0x71, 0x80, 0x00, 0x13, 0x30, 0xFF, 0x3F, 0x00, 0xC1, 0x00, 0x00, 0x00, 0x75, 0xC0, 0x7F, 0xFF, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00];
	
	var contents = new DataView(new Uint8Array(data).buffer);
	// Read character offsets
	this.characterGraphics = { male: [], female: [] };
	var paletteImage = new PaletteImage();
	var characterCount = contents.getInt8(0x06);
	var contentOffset = 0x07;
	for (var characterIndex = 0; characterIndex < characterCount; ++characterIndex, contentOffset += 0x230) {
		var gender = contents.getUint8(contentOffset);
		paletteImage.loadFromCharacterGraphicsFile(contents, contentOffset);
		if (gender == 1) {
			this.characterGraphics.female.push(paletteImage.imageContent);
		} else {
			this.characterGraphics.male.push(paletteImage.imageContent);
		}
	}
	
}