function Wares(size) {
	this.size = size;
	this.decompressed = [];
	// Taken from https://github.com/Pyrdacor/Ambermoon.net/blob/master/Ambermoon.Data.Legacy/Compression/Lob.cs
	function decompressLob(contents, contentOffset, decodedSize)
	{
		var decodedData = new Array(decodedSize);
		var decodeIndex = 0;
		var matchOffset;
		var matchLength;
		var matchIndex;
		var readerOffset = 0;

		while (decodeIndex < decodedSize)
		{
			var header = contents.getUint8(contentOffset + (readerOffset++));

			for (var i = 0; i < 8; ++i)
			{
				if ((header & 0x80) == 0) // match
				{
					matchOffset = contents.getUint8(contentOffset + (readerOffset++));
					matchLength = (matchOffset & 0x000f) + 3;
					matchOffset <<= 4;
					matchOffset &= 0xff00;
					matchOffset |= contents.getUint8(contentOffset + (readerOffset++));
					matchIndex = decodeIndex - matchOffset;

					while (matchLength-- != 0)
					{
						decodedData[decodeIndex++] = decodedData[matchIndex++];
					}
				}
				else // normal byte
				{
					decodedData[decodeIndex++] = contents.getUint8(contentOffset + (readerOffset++));
				}

				if (decodeIndex == decodedSize)
					break;

				header <<= 1;
			}
		}

		return decodedData;
	}
	
	this.readFromLOBCompressed = function(contents, contentOffset) {
		var offset = 0x04; // Skip LOB header {0x01, 0x4C, 0x4F, 0x42} (0x01, "LOB")
		var decompressedSize = contents.getUint32(contentOffset + offset) & 0x00ffffff; // first byte always contains 0x06
		offset += 0x04;
		var compressedSize = contents.getUint32(contentOffset + offset);
		offset += 0x04;
		this.decompressed = new DataView(new Uint8Array(decompressLob(contents, contentOffset + offset, decompressedSize)).buffer);
		offset += compressedSize;
	}
	
}

function AmberDevReader() {
	this.readSingleFile = function(e) {
	  var file = e.target.files[0];
	  if (!file) {
		return;
	  }
	  var reader = new FileReader();
	  reader.onload = function(e) {
		var contents = new DataView(e.target.result);
		// Read wares offsets
		var wares = [];
		var waresCount = 1;
		var contentOffset = 0x00;
		// Read wares
		var allWaresBinary = "";
		for (var waresIndex = 0; waresIndex < waresCount; ++waresIndex) {
			var currentWares = new Wares(1);
			currentWares.readFromLOBCompressed(contents, contentOffset);
			contentOffset += currentWares.size;
			// Convert to hex string
			var decompressedArray = new Uint8Array(currentWares.decompressed.buffer);
			var b = decompressedArray.map(function (x) {
				x = x + 0xFF + 1;  // twos complement
				x = x.toString(16); // to hex
				x = ("00"+x).substr(-2); // zero-pad to 2-digits
				return x
			}).join('');
			allWaresBinary += b;
		}
		console.log(allWaresBinary);
		debugger;
	  };
	  reader.readAsArrayBuffer(file);
	}
}

function ItemsReader() {
	this.readUncompressed = function(decompressed) {
		// Convert to hex string
		var decompressedArray = new Uint8Array(decompressed.buffer);
		var numberToHex = function (x) {
			x = x + 0xFF + 1;  // twos complement
			x = x.toString(16); // to hex
			x = ("00"+x).substr(-2); // zero-pad to 2-digits
			return x;
		};
		var binaryChars = Array.prototype.map.call(decompressedArray, numberToHex);
		var b = binaryChars.join('');
		return b;
	}
	this.readSingleFile = function(e) {
	  var itemsReader = this;
	  var file = e.target.files[0];
	  if (!file) {
		return;
	  }
	  var reader = new FileReader();
	  reader.onload = function(e) {
		var contents = new DataView(e.target.result);
		// Read wares offsets
		var wares = [];
		var waresCount = contents.getInt16(0x04);
		var contentOffset = 0x06;
		for (var waresIndex = 0; waresIndex < waresCount; ++waresIndex, contentOffset += 0x04) {
			var waresSize = contents.getInt16(contentOffset + 0x02);
			wares.push(new Wares(waresSize));
		}
		// Read wares
		var allWaresBinary = "";
		for (var waresIndex = 0; waresIndex < waresCount; ++waresIndex) {
			var currentWares = wares[waresIndex];
			currentWares.readFromLOBCompressed(contents, contentOffset);
			contentOffset += currentWares.size;
			var b = itemsReader.readUncompressed(currentWares.decompressed);
			allWaresBinary += '\r\nWares ' + waresIndex + ':\r\n' + b;
		}
		console.log(allWaresBinary);
		debugger;
	  };
	  reader.readAsArrayBuffer(file);
	}
}

function IconsReader() {
	//this.offset = offset;
	this.icons = [];
	this.readIconData = function(contents) {
		//if (contents.getUint32(0) != 0x00021101) {
		//	return;
		//}
		var offset = 0x48; //<-- LABBLOCK.AMB //ICON.DAT: 0x814; // Unknown data at beginning
		while ((offset + 0x10) < contents.byteLength) {
			// Read icon dimensions
			var iconSize = contents.getUint32(offset) - 0x06;
			var width = contents.getUint16(offset + 0x04) + 1; // When the number is 0x0E (14), the width is 16
			var height = contents.getUint16(offset + 0x04 + 0x02) + 1; // When the number is 0x0F (15), the height is 16
			var bitDepth = contents.getUint16(offset + 0x04 + 0x04);
			var icon = new PaletteImageIcon(width,height,bitDepth);
			icon.loadPaletteImage(contents, offset + 0x04 + 0x06, iconSize);
			icon.paintCanvas();
			this.icons.push(icon);
			// 0x04 = IconSize given in file, 0x06 = IconHeader
			offset += (iconSize + 0x04 + 0x06);
		}
	}
}

function LobReader() {
	this.readSingleFile = function(e,uncompressedReader,onFinished) {
	  var file = e.target.files[0];
	  if (!file) {
		return;
	  }
	  var reader = new FileReader();
	  reader.onload = function(e) {
		var contents = new DataView(e.target.result);
		// Read wares offsets
		var wares = [];
		var waresCount = contents.getInt16(0x04);
		var contentOffset = 0x06;
		for (var waresIndex = 0; waresIndex < waresCount; ++waresIndex, contentOffset += 0x04) {
			var waresSize = contents.getInt16(contentOffset + 0x02);
			wares.push(new Wares(waresSize));
		}
		// Read icons
		for (var waresIndex = 0; waresIndex < waresCount; ++waresIndex) {
			var currentWares = wares[waresIndex];
			currentWares.readFromLOBCompressed(contents, contentOffset);
			contentOffset += currentWares.size;
			if (waresIndex >= 3) { // Skip first 3 for LABBLOCK
				uncompressedReader(currentWares.decompressed);
			}
		}
		onFinished();
	  };
	  reader.readAsArrayBuffer(file);
	}
}

function SingleLobReader() {
	this.readSingleFile = function(e,uncompressedReader,onFinished) {
	  var file = e.target.files[0];
	  if (!file) {
		return;
	  }
	  var reader = new FileReader();
	  reader.onload = function(e) {
		var contents = new DataView(e.target.result);
		var contentOffset = 0x00;
		var currentWares = new Wares(contents.length);
		currentWares.readFromLOBCompressed(contents, contentOffset);
		uncompressedReader(currentWares.decompressed);
		onFinished();
	  };
	  reader.readAsArrayBuffer(file);
	}
}